!******************************************************************************!
!                                                                              !
!    class_vertices.f90                                                        !
!    is part of RECOLA2 (REcursive Computation of One Loop Amplitudes)2        !
!                                                                              !
!    Copyright (C) 2016-2018 Ansgar Denner, Jean-Nicolas Lang and              !
!                            Sandro Uccirati                                   !
!                                                                              !
!    RECOLA2 is licenced under the GNU GPL version 3,                          !
!    see COPYING for details.                                                  !
!                                                                              !
!******************************************************************************!
!                                                           .---.              !
!                                                          /  .  \             !
!                                                         |\_/|   |            !
!                                                         |   |  /|            !
!          .----------------------------------------------------' |            !
!         /  .-.   class_vertices.f90                             |            !
!        |  /   \  This code was generated with REPT1L.           |            !
!        | |\_.  | Change this file and you get what you deserve. |            !
!        |\|  | /| Author: J.N. Lang                              |            !
!        | `---' | UFO date: 11/2018                              |            !
!        |       | UFO version: 1.0                               |            !
!        |       | Generation date: 2018-11-14 17:03             /             !
!        |       |----------------------------------------------'              !
!        \       |                                                             !
!         \     /                                                              !
!          `---'                                                               !
!******************************************************************************!
module class_vertices
  use fill_couplings
  use class_particles
  use class_ctparameters
  use fill_ctparameters, only: init_CTparameters_mdl
  use particle_keys, only: createParticleConfig
  use dictionary, only: dict,dict_get_value,dict_init
  use constants_mdl, only: Nc
  implicit none
  save

  interface get_vertex_mdl
    module procedure get_vertex3_mdl, get_vertex4_mdl, get_vertexN_mdl
  end interface

  type Branch
    integer :: lorentz_id
    integer :: perm
    integer, allocatable :: couplings(:)
    integer, dimension(n_orders) :: coupling_order
    integer :: color_id
    integer :: colorfac_id
    ! Propagator extension (only supported for massive vectors)
    ! 0: Usual propagator
    ! 1: Rxi-propagator part with pole @ M_V^2
    ! 2: Rxi-propagator part with pole @ \xi*M_V^2
    integer :: pext
  end type

  type Vertex
    type(Branch), allocatable :: branch(:)
    type(Branch), allocatable :: branchCT(:)
    type(Branch), allocatable :: branchR2(:)
  end type

  logical :: vertices_init = .false.
  logical :: vertices_filled = .false.
    interface createCurrent
      module procedure createCurrent2, createCurrent3, createCurrent4,         &
      createCurrent5, createCurrent6, createCurrent7, createCurrent8
    end interface 
  integer, parameter :: n_vertices = 1682
  type(Vertex) :: vertices(0:n_vertices-1)

  ! Defines the maximum allowed number of legs participating at a vertex
  integer, parameter :: max_leg_multiplicity = 4

  integer, parameter :: FFaS0 = 1
  integer, parameter :: FFaS1 = 2
  integer, parameter :: FFaS2 = 3
  integer, parameter :: VFaF0 = 4
  integer, parameter :: VFaF1 = 5
  integer, parameter :: SVVS0 = 6
  integer, parameter :: VVS0 = 7
  integer, parameter :: UUaS0 = 8
  integer, parameter :: UUaV0 = 9
  integer, parameter :: USUa0 = 10
  integer, parameter :: SUUa0 = 11
  integer, parameter :: VVSS0 = 12
  integer, parameter :: FaF0 = 13
  integer, parameter :: FaF1 = 14
  integer, parameter :: FFaV0 = 15
  integer, parameter :: FFaV1 = 16
  integer, parameter :: VVV0 = 17
  integer, parameter :: VVV1 = 18
  integer, parameter :: FSFa0 = 19
  integer, parameter :: FSFa1 = 20
  integer, parameter :: FSFa2 = 21
  integer, parameter :: VVVV0 = 22
  integer, parameter :: VVVV1 = 23
  integer, parameter :: FaVF0 = 24
  integer, parameter :: FaVF1 = 25
  integer, parameter :: FaFS0 = 26
  integer, parameter :: FaFS1 = 27
  integer, parameter :: FaFS2 = 28
  integer, parameter :: UaVU0 = 29
  integer, parameter :: VSVS0 = 30
  integer, parameter :: FVFa0 = 31
  integer, parameter :: FVFa1 = 32
  integer, parameter :: VUaU0 = 33
  integer, parameter :: VV0 = 34
  integer, parameter :: VV1 = 35
  integer, parameter :: VV2 = 36
  integer, parameter :: SVSV0 = 37
  integer, parameter :: UaSU0 = 38
  integer, parameter :: FaFV0 = 39
  integer, parameter :: FaFV1 = 40
  integer, parameter :: SSSS0 = 41
  integer, parameter :: VS0 = 42
  integer, parameter :: SFFa0 = 43
  integer, parameter :: SFFa1 = 44
  integer, parameter :: SFFa2 = 45
  integer, parameter :: VUUa0 = 46
  integer, parameter :: SFaF0 = 47
  integer, parameter :: SFaF1 = 48
  integer, parameter :: SFaF2 = 49
  integer, parameter :: SVV0 = 50
  integer, parameter :: FaSF0 = 51
  integer, parameter :: FaSF1 = 52
  integer, parameter :: FaSF2 = 53
  integer, parameter :: SVS0 = 54
  integer, parameter :: FFa0 = 55
  integer, parameter :: FFa1 = 56
  integer, parameter :: VSS0 = 57
  integer, parameter :: VSV0 = 58
  integer, parameter :: SS0 = 59
  integer, parameter :: SSVV0 = 60
  integer, parameter :: SSV0 = 61
  integer, parameter :: SV0 = 62
  integer, parameter :: SSS0 = 63
  integer, parameter :: UVUa0 = 64
  integer, parameter :: VSSV0 = 65
  integer, parameter :: UaUS0 = 66
  integer, parameter :: VFFa0 = 67
  integer, parameter :: VFFa1 = 68
  integer, parameter :: SUaU0 = 69
  integer, parameter :: UaUV0 = 70
  complex(dp), parameter :: c1 = cmplx(1d0, 0d0, kind=dp)
  character(len=20), parameter :: c1f = "1"
  complex(dp), parameter :: c2 = cmplx(sq2/2d0, 0d0, kind=dp)
  character(len=20), parameter :: c2f = "sq2/2"
  complex(dp), parameter :: c3 = cmplx(-sq2/(2d0*Nc), 0d0, kind=dp)
  character(len=20), parameter :: c3f = "-sq2/(2*Nc)"
  complex(dp), parameter :: c4 = cmplx(0d0, sq2/2d0, kind=dp)
  character(len=20), parameter :: c4f = "i_*sq2/2"
  complex(dp), parameter :: c5 = cmplx(0d0, -sq2/2d0, kind=dp)
  character(len=20), parameter :: c5f = "-i_*sq2/2"
  complex(dp), parameter :: c6 = cmplx(1d0/2d0, 0d0, kind=dp)
  character(len=20), parameter :: c6f = "1/2"
  complex(dp), parameter :: c7 = cmplx(-1d0/2d0, 0d0, kind=dp)
  character(len=20), parameter :: c7f = "-1/2"
  complex(dp), parameter :: c8 = cmplx(-1d0/Nc, 0d0, kind=dp)
  character(len=20), parameter :: c8f = "-1/Nc"
  complex(dp), dimension(1:8) :: colorcoeffs = (/c1, c2, c3, c4, c5, c6, c7, c8&
                                               /)
  character(len=20), dimension(1:8) :: colorcoeffs_form = (/c1f, c2f, c3f, c4f &
                 , c5f, c6f, c7f, c8f/)
  integer, dimension(1:70) :: lorentz_rank = (/0, 0, 0, 1, 1, 0, 0, 0, 1, 0, 0 &
                                             , 0, -1, -1, 0, 0, 1, -1, 1, 1, 1 &
                                             , 0, -1, 1, 1, 0, 0, 0, 1, 0, 1, 1&
                                             , 1, -1, -1, -1, 0, 0, 0, 0, 0, -1&
                                             , 1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1 &
                                             , 1, -1, -1, 1, 0, -1, 0, 1, -1, 0&
                                             , 1, 0, 0, 1, 1, 0, 1/)
  integer, dimension(1:70) :: recola_base = (/0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, &
                                            0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 &
                                            , 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, &
                                            0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 &
                                            , 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, &
                                            0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 &
                                            , 0/)
  integer, dimension(1:70) :: propagator_extension = (/0, 0, 0, 0, 0, 0, 0, 0, &
                                                     0, 0, 0, 0, 0, 0, 0, 0, 0 &
                                                     , 0, 0, 0, 0, 0, 0, 0, 0, &
                                                     0, 0, 0, 0, 0, 0, 0, 0, 0 &
                                                     , 0, 0, 0, 0, 0, 0, 0, 0, &
                                                     0, 0, 0, 0, 0, 0, 0, 0, 0 &
                                                     , 0, 0, 0, 0, 0, 0, 0, 0, &
                                                     0, 0, 0, 0, 0, 0, 0, 0, 0 &
                                                     , 0, 0/)
  character(len=*), parameter :: model_timestamp = "Wed Nov 14 16:49:40 2018"

  contains
    function get_timestamp_mdl() result(ret_timestamp)
      character(len=len(model_timestamp)) :: ret_timestamp
      ret_timestamp = model_timestamp
    end function get_timestamp_mdl

    function get_lorentz_rank_mdl(l_id) result(ret_lorentz_rank)
      integer, intent(in) :: l_id
      integer :: ret_lorentz_rank
      ret_lorentz_rank = lorentz_rank(l_id)
    end function get_lorentz_rank_mdl

    function get_propagator_extension_mdl(l_id) result(ret_pext)
      integer, intent(in) :: l_id
      integer :: ret_pext
      ret_pext = propagator_extension(l_id)
    end function get_propagator_extension_mdl

    function get_max_leg_multiplicity_mdl() result(ret_max_leg_multiplicity)
      integer :: ret_max_leg_multiplicity
      ret_max_leg_multiplicity = max_leg_multiplicity
    end function get_max_leg_multiplicity_mdl

    function is_model_init_mdl() result(ret_init)
      logical :: ret_init
      ret_init = vertices_init
    end function is_model_init_mdl

    function is_model_filled_mdl() result(ret_init)
      logical :: ret_init
      ret_init = vertices_filled
    end function is_model_filled_mdl

    subroutine get_vertex3_mdl(p1, p2, p3, vertex_ret)
      integer, intent(out) :: vertex_ret
      integer, intent(in)  :: p1, p2, p3
      integer(kind=8)      :: config
      integer              :: address
      logical              :: found_vertex

      call createParticleConfig(p1, p2, p3, config)
      call dict(config, 1, address, found_vertex, 0)
      if(found_vertex) then
        vertex_ret = dict_get_value(address)
      else
        vertex_ret = -1
      end if

    end subroutine get_vertex3_mdl

    subroutine get_vertex4_mdl(p1, p2, p3, p4, vertex_ret)
      integer, intent(out) :: vertex_ret
      integer, intent(in)  :: p1, p2, p3, p4
      integer(kind=8)      :: config
      integer              :: address
      logical              :: found_vertex

      call createParticleConfig(p1, p2, p3, p4, config)
      call dict(config, 1, address, found_vertex, 0)
      if(found_vertex) then
        vertex_ret = dict_get_value(address)
      else
        vertex_ret = -1
      end if
    end subroutine get_vertex4_mdl

    subroutine get_vertexN_mdl(particles, particleOut, vertex_ret)
      integer, intent(out)              :: vertex_ret
      integer, dimension(:), intent(in) :: particles
      integer, intent(in)               :: particleOut
      integer(kind=8)                   :: config
      integer                           :: address
      logical                           :: found_vertex

      call createParticleConfig(particles, particleOut, config)
      call dict(config, 1, address, found_vertex, 0)
      if(found_vertex) then
        vertex_ret = dict_get_value(address)
      else
        vertex_ret = -1
      end if

    end subroutine get_vertexN_mdl

    subroutine av(vid,bid,cid,cfid,pext,lid,perm,co,cop)
      integer, intent(in) :: vid,bid,cid,cfid,pext,lid,perm
      integer, dimension(0:), intent(in) :: co, cop
      integer scop,i
      vertices(vid)%branch(bid)%color_id = cid
      vertices(vid)%branch(bid)%colorfac_id = cfid
      vertices(vid)%branch(bid)%pext = pext
      vertices(vid)%branch(bid)%lorentz_id = lid
      vertices(vid)%branch(bid)%perm = perm
      vertices(vid)%branch(bid)%coupling_order = co
      scop = size(cop)
      allocate(vertices(vid)%branch(bid)%couplings(0:scop-1))
      do i = 0, scop-1
        vertices(vid)%branch(bid)%couplings(i) = cop(i)
      end do
    end subroutine av

    subroutine avCT(vid,bid,cid,cfid,pext,lid,perm,co,cop)
      integer, intent(in) :: vid,bid,cid,cfid,pext,lid,perm
      integer, dimension(0:), intent(in) :: co, cop
      integer scop,i
      vertices(vid)%branchCT(bid)%color_id = cid
      vertices(vid)%branchCT(bid)%colorfac_id = cfid
      vertices(vid)%branchCT(bid)%pext = pext
      vertices(vid)%branchCT(bid)%lorentz_id = lid
      vertices(vid)%branchCT(bid)%perm = perm
      vertices(vid)%branchCT(bid)%coupling_order = co
      scop = size(cop)
      allocate(vertices(vid)%branchCT(bid)%couplings(0:scop-1))
      do i = 0, scop-1
        vertices(vid)%branchCT(bid)%couplings(i) = cop(i)
      end do
    end subroutine avCT

    subroutine avR2(vid,bid,cid,cfid,pext,lid,perm,co,cop)
      integer, intent(in) :: vid,bid,cid,cfid,pext,lid,perm
      integer, dimension(0:), intent(in) :: co, cop
      integer scop,i
      vertices(vid)%branchR2(bid)%color_id = cid
      vertices(vid)%branchR2(bid)%colorfac_id = cfid
      vertices(vid)%branchR2(bid)%pext = pext
      vertices(vid)%branchR2(bid)%lorentz_id = lid
      vertices(vid)%branchR2(bid)%perm = perm
      vertices(vid)%branchR2(bid)%coupling_order = co
      scop = size(cop)
      allocate(vertices(vid)%branchR2(bid)%couplings(0:scop-1))
      do i = 0, scop-1
        vertices(vid)%branchR2(bid)%couplings(i) = cop(i)
      end do
    end subroutine avR2

    function get_colourfac_mdl(cfid)
      integer, intent(in) :: cfid
      complex(dp) :: get_colourfac_mdl
      get_colourfac_mdl = colorcoeffs(cfid)
    end function get_colourfac_mdl

    function get_colourfac_form_mdl(cfid)
      integer, intent(in) :: cfid
      character(len=20) :: get_colourfac_form_mdl
      get_colourfac_form_mdl = colorcoeffs_form(cfid)
    end function get_colourfac_form_mdl

  function get_recola_base_mdl(l_id) result(ret_rb)
      integer, intent(in) :: l_id
      integer :: ret_rb
      ret_rb = recola_base(l_id)
    end function get_recola_base_mdl

  subroutine get_vertex_branch_status_mdl(vx,xlp,branch_exists)
    integer, intent(in)  :: vx,xlp
    logical, intent(out) ::branch_exists
    select case (xlp)
    case(TreeBranch:LoopBranch)
      branch_exists = allocated(vertices(vx)%branch)
    case(CTBranch)
      branch_exists = allocated(vertices(vx)%branchCT)
    case(R2Branch)
      branch_exists = allocated(vertices(vx)%branchR2)
    end select
  end subroutine get_vertex_branch_status_mdl

  subroutine get_vertex_colour_branches_mdl(vx,xlp,cfids,nbranches)
    integer, allocatable, intent(out) :: cfids(:)
    integer, intent(out) :: nbranches
    integer, intent(in)  :: vx,xlp
    select case (xlp)
    case (TreeBranch:LoopBranch)
      allocate(cfids(size(vertices(vx)%branch)))
      cfids(:) = vertices(vx)%branch(0:)%color_id
      nbranches = size(vertices(vx)%branch)
    case(CTBranch)
      allocate(cfids(size(vertices(vx)%branchCT)))
      cfids(:) = vertices(vx)%branchCT(0:)%color_id
      nbranches = size(vertices(vx)%branchCT)
    case(R2Branch)
      allocate(cfids(size(vertices(vx)%branchR2)))
      cfids(:) = vertices(vx)%branchR2(0:)%color_id
      nbranches = size(vertices(vx)%branchR2)
    end select
  end subroutine get_vertex_colour_branches_mdl

  subroutine get_vertex_pext_mdl(vx,xlp,br,pext)
    integer, intent(in) :: vx,xlp,br
    integer, intent(out) :: pext
    select case (xlp)
    case (TreeBranch:LoopBranch)
      pext = vertices(vx)%branch(br)%pext
    case(CTBranch)
      pext = vertices(vx)%branchCT(br)%pext
    case(R2Branch)
      pext = vertices(vx)%branchR2(br)%pext
    end select
  end subroutine get_vertex_pext_mdl

  subroutine get_vertex_order_increase_mdl(vx,xlp,br,orderInc)
    integer, intent(in) :: vx,xlp,br
    integer, dimension(:), intent(out) :: orderInc
    select case (xlp)
    case (TreeBranch:LoopBranch)
      orderInc = vertices(vx)%branch(br)%coupling_order
    case(CTBranch)
      orderInc = vertices(vx)%branchCT(br)%coupling_order
    case(R2Branch)
      orderInc = vertices(vx)%branchR2(br)%coupling_order
    end select
  end subroutine get_vertex_order_increase_mdl

  subroutine get_vertex_lorentz_type_mdl(vx,xlp,br,lid)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: lid
    select case (xlp)
    case (TreeBranch:LoopBranch)
      lid = vertices(vx)%branch(br)%lorentz_id
    case(CTBranch)
      lid = vertices(vx)%branchCT(br)%lorentz_id
    case(R2Branch)
      lid = vertices(vx)%branchR2(br)%lorentz_id
    end select
  end subroutine get_vertex_lorentz_type_mdl

  subroutine get_vertex_perm_mdl(vx,xlp,br,perm)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: perm
    select case (xlp)
    case (TreeBranch:LoopBranch)
      perm = vertices(vx)%branch(br)%perm
    case(CTBranch)
      perm = vertices(vx)%branchCT(br)%perm
    case(R2Branch)
      perm = vertices(vx)%branchR2(br)%perm
    end select
  end subroutine get_vertex_perm_mdl

  subroutine get_vertex_colour_id_mdl(vx,xlp,br,cid)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: cid
    select case (xlp)
    case (TreeBranch:LoopBranch)
      cid = vertices(vx)%branch(br)%colorfac_id
    case(CTBranch)
      cid = vertices(vx)%branchCT(br)%colorfac_id
    case(R2Branch)
      cid = vertices(vx)%branchR2(br)%colorfac_id
    end select
  end subroutine get_vertex_colour_id_mdl

  function is_zero_coupling_vertex_mdl(vx,xlp,br) result(zero)
    use class_couplings, only: get_coupling_value_mdl
    use input_mdl, only: zerocut
    integer, intent(in)  :: vx,xlp,br
    logical              :: zero
    real(dp)             :: maxvalue
    integer              :: i

    zero = .false.
    select case (xlp)
    case (TreeBranch:LoopBranch)
      maxvalue = 0d0
      do i = 1,size(vertices(vx)%branch(br)%couplings)
        maxvalue = maxvalue + &
                abs(get_coupling_value_mdl(vertices(vx)%branch(br)%couplings(i-&
                1)))
      end do
      if (maxvalue/zerocut .lt. 100d0) then
        zero = .true.
      end if
    case(CTBranch)
      maxvalue = 0d0
      do i = 1,size(vertices(vx)%branchCT(br)%couplings)
        maxvalue = maxvalue + &
                abs(get_coupling_value_mdl(vertices(vx)%branchCT(br)%couplings(&
                i-1)))
      end do
      if (maxvalue/zerocut .lt. 100d0) then
        zero = .true.
      end if
    case(R2Branch)
      maxvalue = 0d0
      do i = 1,size(vertices(vx)%branchR2(br)%couplings)
        maxvalue = maxvalue + &
                abs(get_coupling_value_mdl(vertices(vx)%branchR2(br)%couplings(&
                i-1)))
      end do
      if (maxvalue/zerocut .lt. 100d0) then
        zero = .true.
      end if
    end select
  end function is_zero_coupling_vertex_mdl

  subroutine get_vertex_ncouplings_mdl(vx,xlp,br,ncouplings)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: ncouplings
    select case(xlp)
    case(TreeBranch, LoopBranch)
      ncouplings = size(vertices(vx)%branch(br)%couplings)
    case (CTBranch)
      ncouplings = size(vertices(vx)%branchCT(br)%couplings)
    case (R2Branch)
      ncouplings = size(vertices(vx)%branchR2(br)%couplings)
    end select
  end subroutine get_vertex_ncouplings_mdl

  subroutine get_vertex_coupling_ids_mdl(vx,xlp,br,cids)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: cids(:)
    select case(xlp)
    case(TreeBranch, LoopBranch)
      cids(:) = vertices(vx)%branch(br)%couplings(:)
    case (CTBranch)
      cids(:) = vertices(vx)%branchCT(br)%couplings(:)
    case (R2Branch)
      cids(:) = vertices(vx)%branchR2(br)%couplings(:)
    end select
  end subroutine get_vertex_coupling_ids_mdl

    subroutine createCurrent2(P1, P2, id, check)
      integer, intent(in) :: P1, P2, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent2

    subroutine createCurrent3(P1, P2, P3, id, check)
      integer, intent(in) :: P1, P2, P3, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent3

    subroutine createCurrent4(P1, P2, P3, P4, id, check)
      integer, intent(in) :: P1, P2, P3, P4, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent4

    subroutine createCurrent5(P1, P2, P3, P4, P5, id, check)
      integer, intent(in) :: P1, P2, P3, P4, P5, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent5

    subroutine createCurrent6(P1, P2, P3, P4, P5, P6, id, check)
      integer, intent(in) :: P1, P2, P3, P4, P5, P6, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, P6, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent6

    subroutine createCurrent7(P1, P2, P3, P4, P5, P6, P7, id, check)
      integer, intent(in) :: P1, P2, P3, P4, P5, P6, P7, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, P6, P7, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent7

    subroutine createCurrent8(P1, P2, P3, P4, P5, P6, P7, P8, id, check)
      integer, intent(in) :: P1, P2, P3, P4, P5, P6, P7, P8, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, P6, P7, P8, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent8

    subroutine init_vertices_mdl()
      use constants_mdl
      use input_mdl, only: nx, error_mdl

      ! check if modelfile is compatible to drivers
      if (model_timestamp .ne. driver_timestamp) then
        call error_mdl("Model corrupted. Driver timestamp mismatch.", &
                      where='init_vertices')
      end if

      vertices_init = .true.
      call fill_couplings_mdl
      call init_CTparameters_mdl(.true.)
      call fill_CTcouplings_mdl
      call dict_init(3361)
      call createCurrents(.false.)

    end subroutine init_vertices_mdl

    subroutine createCurrents(check)
      logical, intent(in) :: check
      call createCurrent(P_GMinus, P_G0, P_A, P_WPlus, 1035, check)
      call createCurrent(P_WPlus, P_GPlus, P_GMinus, P_WMinus, 1049, check)
      call createCurrent(P_GPlus, P_b, P_tAnti, 1115, check)
      call createCurrent(P_b, P_bAnti, P_g, 1374, check)
      call createCurrent(P_muPlus, P_Zp, P_tauMinus, 724, check)
      call createCurrent(P_GPlus, P_A, P_Z, P_GMinus, 698, check)
      call createCurrent(P_G0, P_WMinus, P_WPlus, P_G0, 710, check)
      call createCurrent(P_WpPlus, P_tAnti, P_s, 417, check)
      call createCurrent(P_WMinus, P_GPlus, P_A, P_H, 174, check)
      call createCurrent(P_WpMinus, P_dAnti, P_t, 532, check)
      call createCurrent(P_Z, P_GPlus, P_H, P_WMinus, 1428, check)
      call createCurrent(P_GPlus, P_uAnti, P_s, 410, check)
      call createCurrent(P_H, P_WMinus, P_WPlus, 730, check)
      call createCurrent(P_WpPlus, P_s, P_cAnti, 1154, check)
      call createCurrent(P_G0, P_G0, P_G0, P_G0, 797, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_G0, 8, check)
      call createCurrent(P_s, P_sAnti, P_H, 576, check)
      call createCurrent(P_cAnti, P_WpPlus, P_d, 403, check)
      call createCurrent(P_WpMinus, P_nu_e, P_ePlus, 154, check)
      call createCurrent(P_g, P_cAnti, P_c, 1013, check)
      call createCurrent(P_WMinus, P_G0, P_G0, P_WPlus, 969, check)
      call createCurrent(P_WPlus, P_g, P_WpMinus, P_g, 1627, check)
      call createCurrent(P_Z, P_WMinus, P_WPlus, 443, check)
      call createCurrent(P_Zp, P_s, P_sAnti, 922, check)
      call createCurrent(P_sAnti, P_g, P_s, 115, check)
      call createCurrent(P_u, P_cAnti, P_Zp, 1070, check)
      call createCurrent(P_c, P_GMinus, P_dAnti, 1359, check)
      call createCurrent(P_Zp, P_b, P_dAnti, 573, check)
      call createCurrent(P_A, P_ePlus, P_eMinus, 843, check)
      call createCurrent(P_s, P_WpPlus, P_cAnti, 536, check)
      call createCurrent(P_nu_e, P_ePlus, P_WpMinus, 290, check)
      call createCurrent(P_WMinus, P_H, P_WPlus, P_H, 1144, check)
      call createCurrent(P_G0, P_GPlus, P_WMinus, P_A, 1267, check)
      call createCurrent(P_nu_eAnti, P_eMinus, P_GPlus, 149, check)
      call createCurrent(P_tauMinus, P_WpPlus, P_nu_tauAnti, 42, check)
      call createCurrent(P_Z, P_tauPlus, P_tauMinus, 1210, check)
      call createCurrent(P_WMinus, P_dAnti, P_u, 646, check)
      call createCurrent(P_H, P_WPlus, P_A, P_GMinus, 790, check)
      call createCurrent(P_WPlus, P_WMinus, P_H, P_H, 711, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_ghA, 111, check)
      call createCurrent(P_Z, P_WPlus, P_A, P_WMinus, 762, check)
      call createCurrent(P_WPlus, P_Z, P_A, P_WMinus, 528, check)
      call createCurrent(P_tauMinus, P_nu_tauAnti, P_GPlus, 1162, check)
      call createCurrent(P_Z, P_WPlus, P_Z, P_WMinus, 1080, check)
      call createCurrent(P_WMinus, P_H, P_Z, P_GPlus, 786, check)
      call createCurrent(P_ePlus, P_WpMinus, P_nu_e, 1135, check)
      call createCurrent(P_Zp, P_d, P_bAnti, 670, check)
      call createCurrent(P_A, P_ghWm, P_ghWmAnti, 1007, check)
      call createCurrent(P_bAnti, P_b, P_g, 563, check)
      call createCurrent(P_cAnti, P_Z, P_c, 114, check)
      call createCurrent(P_eMinus, P_WPlus, P_nu_eAnti, 303, check)
      call createCurrent(P_Zp, P_tauMinus, P_ePlus, 246, check)
      call createCurrent(P_GPlus, P_GMinus, P_WPlus, P_WMinus, 1427, check)
      call createCurrent(P_Z, P_ePlus, P_eMinus, 669, check)
      call createCurrent(P_A, P_tauPlus, P_tauMinus, 611, check)
      call createCurrent(P_Z, P_WPlus, P_WMinus, P_Z, 207, check)
      call createCurrent(P_t, P_Z, P_tAnti, 1366, check)
      call createCurrent(P_G0, P_dAnti, P_d, 1261, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_ghWp, 1145, check)
      call createCurrent(P_s, P_Z, P_sAnti, 928, check)
      call createCurrent(P_GMinus, P_A, P_GPlus, P_Z, 665, check)
      call createCurrent(P_nu_e, P_WMinus, P_ePlus, 517, check)
      call createCurrent(P_H, P_cAnti, P_c, 192, check)
      call createCurrent(P_bAnti, P_b, P_Z, 1357, check)
      call createCurrent(P_H, P_H, P_GPlus, P_GMinus, 120, check)
      call createCurrent(P_GMinus, P_WPlus, P_G0, P_Z, 857, check)
      call createCurrent(P_H, P_sAnti, P_d, 129, check)
      call createCurrent(P_A, P_muPlus, P_muMinus, 1432, check)
      call createCurrent(P_WMinus, P_GMinus, P_GPlus, P_WPlus, 765, check)
      call createCurrent(P_H, P_Z, P_GMinus, P_WPlus, 643, check)
      call createCurrent(P_G0, P_uAnti, P_u, 1398, check)
      call createCurrent(P_nu_e, P_WpMinus, P_ePlus, 415, check)
      call createCurrent(P_G0, P_c, P_cAnti, 1001, check)
      call createCurrent(P_s, P_uAnti, P_GPlus, 814, check)
      call createCurrent(P_GMinus, P_WPlus, P_G0, 254, check)
      call createCurrent(P_nu_mu, P_nu_muAnti, P_Z, 485, check)
      call createCurrent(P_g, P_H, P_H, P_g, 1612, check)
      call createCurrent(P_WpPlus, P_WMinus, P_g, P_g, 1621, check)
      call createCurrent(P_GPlus, P_A, P_WMinus, P_G0, 1460, check)
      call createCurrent(P_g, P_g, P_Z, P_Zp, 1567, check)
      call createCurrent(P_Zp, P_sAnti, P_b, 127, check)
      call createCurrent(P_uAnti, P_s, P_WpPlus, 135, check)
      call createCurrent(P_sAnti, P_WpMinus, P_u, 877, check)
      call createCurrent(P_WMinus, P_g, P_WPlus, P_g, 1631, check)
      call createCurrent(P_muMinus, P_nu_muAnti, P_WPlus, 1472, check)
      call createCurrent(P_tauMinus, P_Zp, P_muPlus, 1009, check)
      call createCurrent(P_dAnti, P_t, P_WpMinus, 416, check)
      call createCurrent(P_Z, P_WMinus, P_GPlus, P_G0, 1211, check)
      call createCurrent(P_sAnti, P_s, P_H, 581, check)
      call createCurrent(P_A, P_H, P_GMinus, P_WPlus, 937, check)
      call createCurrent(P_dAnti, P_d, P_A, 1396, check)
      call createCurrent(P_WpPlus, P_WpMinus, P_g, P_g, 1608, check)
      call createCurrent(P_d, P_A, P_dAnti, 213, check)
      call createCurrent(P_Z, P_uAnti, P_u, 826, check)
      call createCurrent(P_H, P_muMinus, P_muPlus, 309, check)
      call createCurrent(P_tauMinus, P_H, P_tauPlus, 183, check)
      call createCurrent(P_Z, P_WMinus, P_G0, P_GPlus, 1071, check)
      call createCurrent(P_Zp, P_A, P_g, P_g, 1548, check)
      call createCurrent(P_muMinus, P_GPlus, P_nu_muAnti, 1010, check)
      call createCurrent(P_GPlus, P_H, P_GMinus, P_H, 98, check)
      call createCurrent(P_WMinus, P_GPlus, P_H, 381, check)
      call createCurrent(P_Zp, P_cAnti, P_u, 953, check)
      call createCurrent(P_c, P_cAnti, P_Zp, 1098, check)
      call createCurrent(P_dAnti, P_g, P_d, 378, check)
      call createCurrent(P_WpMinus, P_muPlus, P_nu_e, 189, check)
      call createCurrent(P_c, P_cAnti, P_A, 768, check)
      call createCurrent(P_Zp, P_g, P_g, P_Z, 1606, check)
      call createCurrent(P_tauMinus, P_nu_muAnti, P_WpPlus, 1072, check)
      call createCurrent(P_H, P_dAnti, P_s, 1159, check)
      call createCurrent(P_WPlus, P_g, P_WMinus, P_g, 1616, check)
      call createCurrent(P_cAnti, P_GPlus, P_d, 917, check)
      call createCurrent(P_G0, P_sAnti, P_d, 266, check)
      call createCurrent(P_tAnti, P_t, P_A, 217, check)
      call createCurrent(P_tauMinus, P_tauPlus, 1537, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_GPlus, 1277, check)
      call createCurrent(P_b, P_WpPlus, P_cAnti, 1434, check)
      call createCurrent(P_GPlus, P_A, P_WMinus, P_H, 915, check)
      call createCurrent(P_eMinus, P_muPlus, P_Zp, 1024, check)
      call createCurrent(P_c, P_sAnti, P_WMinus, 1046, check)
      call createCurrent(P_c, P_WpMinus, P_dAnti, 435, check)
      call createCurrent(P_A, P_d, P_dAnti, 397, check)
      call createCurrent(P_dAnti, P_c, P_WMinus, 380, check)
      call createCurrent(P_H, P_WPlus, P_WMinus, 1387, check)
      call createCurrent(P_GPlus, P_tauMinus, P_nu_tauAnti, 1417, check)
      call createCurrent(P_H, P_H, P_H, 1323, check)
      call createCurrent(P_WPlus, P_ghZ, P_ghWpAnti, 772, check)
      call createCurrent(P_muPlus, P_nu_mu, P_WMinus, 674, check)
      call createCurrent(P_d, P_WpPlus, P_tAnti, 870, check)
      call createCurrent(P_g, P_WpMinus, P_g, P_WpPlus, 1557, check)
      call createCurrent(P_muMinus, P_Zp, P_tauPlus, 1239, check)
      call createCurrent(P_H, P_WPlus, P_GMinus, P_A, 317, check)
      call createCurrent(P_u, P_bAnti, P_WpMinus, 626, check)
      call createCurrent(P_uAnti, P_u, 1509, check)
      call createCurrent(P_WpMinus, P_bAnti, P_c, 308, check)
      call createCurrent(P_Zp, P_bAnti, P_d, 1063, check)
      call createCurrent(P_Z, P_G0, P_WMinus, P_GPlus, 1262, check)
      call createCurrent(P_sAnti, P_A, P_s, 990, check)
      call createCurrent(P_Z, P_GPlus, P_GMinus, P_A, 357, check)
      call createCurrent(P_WMinus, P_GPlus, P_WPlus, P_GMinus, 1233, check)
      call createCurrent(P_nu_eAnti, P_eMinus, P_WpPlus, 234, check)
      call createCurrent(P_nu_muAnti, P_WpPlus, P_muMinus, 1416, check)
      call createCurrent(P_eMinus, P_ePlus, P_Zp, 1012, check)
      call createCurrent(P_uAnti, P_WPlus, P_s, 1449, check)
      call createCurrent(P_tauPlus, P_Zp, P_tauMinus, 1365, check)
      call createCurrent(P_d, P_H, P_sAnti, 454, check)
      call createCurrent(P_t, P_sAnti, P_WpMinus, 1250, check)
      call createCurrent(P_uAnti, P_WpPlus, P_s, 577, check)
      call createCurrent(P_G0, P_WMinus, P_GPlus, P_A, 1178, check)
      call createCurrent(P_WMinus, P_A, P_GPlus, P_G0, 412, check)
      call createCurrent(P_uAnti, P_u, P_g, 334, check)
      call createCurrent(P_nu_e, P_WpMinus, P_muPlus, 1021, check)
      call createCurrent(P_ePlus, P_eMinus, P_G0, 1241, check)
      call createCurrent(P_ghWp, P_A, P_ghWpAnti, 46, check)
      call createCurrent(P_nu_eAnti, P_muMinus, P_WpPlus, 976, check)
      call createCurrent(P_GMinus, P_H, P_A, P_WPlus, 414, check)
      call createCurrent(P_u, P_uAnti, 1516, check)
      call createCurrent(P_WpPlus, P_g, P_WpMinus, P_g, 1661, check)
      call createCurrent(P_cAnti, P_c, P_Zp, 1361, check)
      call createCurrent(P_sAnti, P_H, P_s, 619, check)
      call createCurrent(P_s, P_WpPlus, P_uAnti, 687, check)
      call createCurrent(P_tAnti, P_t, P_Z, 1368, check)
      call createCurrent(P_WPlus, P_GMinus, P_WMinus, P_GPlus, 1287, check)
      call createCurrent(P_s, P_sAnti, P_Zp, 1384, check)
      call createCurrent(P_cAnti, P_d, P_GPlus, 582, check)
      call createCurrent(P_sAnti, P_s, P_Z, 760, check)
      call createCurrent(P_g, P_WPlus, P_WpMinus, P_g, 1569, check)
      call createCurrent(P_sAnti, P_b, P_Zp, 833, check)
      call createCurrent(P_d, P_cAnti, P_GPlus, 1108, check)
      call createCurrent(P_G0, P_H, P_G0, 148, check)
      call createCurrent(P_WMinus, P_dAnti, P_c, 654, check)
      call createCurrent(P_GPlus, P_WMinus, P_A, P_G0, 1409, check)
      call createCurrent(P_A, P_H, P_WMinus, P_GPlus, 61, check)
      call createCurrent(P_G0, P_Z, P_WPlus, P_GMinus, 848, check)
      call createCurrent(P_Z, P_Z, P_GMinus, P_GPlus, 865, check)
      call createCurrent(P_cAnti, P_c, 1512, check)
      call createCurrent(P_uAnti, P_u, P_Zp, 802, check)
      call createCurrent(P_cAnti, P_Zp, P_t, 707, check)
      call createCurrent(P_c, P_cAnti, P_G0, 157, check)
      call createCurrent(P_WpPlus, P_cAnti, P_b, 341, check)
      call createCurrent(P_GPlus, P_eMinus, P_nu_eAnti, 995, check)
      call createCurrent(P_tauMinus, P_Zp, P_ePlus, 370, check)
      call createCurrent(P_c, P_sAnti, P_WpMinus, 320, check)
      call createCurrent(P_WMinus, P_H, P_WPlus, 1227, check)
      call createCurrent(P_G0, P_tAnti, P_t, 431, check)
      call createCurrent(P_dAnti, P_Zp, P_b, 48, check)
      call createCurrent(P_Z, P_G0, P_Z, P_G0, 225, check)
      call createCurrent(P_bAnti, P_Zp, P_d, 1043, check)
      call createCurrent(P_s, P_dAnti, P_G0, 110, check)
      call createCurrent(P_tauPlus, P_WpMinus, P_nu_e, 706, check)
      call createCurrent(P_s, P_GPlus, P_cAnti, 1050, check)
      call createCurrent(P_cAnti, P_d, P_WPlus, 1229, check)
      call createCurrent(P_WPlus, P_GMinus, P_G0, 713, check)
      call createCurrent(P_GPlus, P_WMinus, P_H, 240, check)
      call createCurrent(P_dAnti, P_d, P_g, 1440, check)
      call createCurrent(P_WMinus, P_G0, P_A, P_GPlus, 638, check)
      call createCurrent(P_c, P_cAnti, 1519, check)
      call createCurrent(P_WMinus, P_H, P_GPlus, P_A, 783, check)
      call createCurrent(P_WpMinus, P_c, P_bAnti, 705, check)
      call createCurrent(P_tauMinus, P_Zp, P_tauPlus, 248, check)
      call createCurrent(P_GPlus, P_s, P_cAnti, 924, check)
      call createCurrent(P_s, P_Zp, P_sAnti, 579, check)
      call createCurrent(P_A, P_H, P_GPlus, P_WMinus, 93, check)
      call createCurrent(P_muPlus, P_muMinus, P_A, 561, check)
      call createCurrent(P_eMinus, P_nu_tauAnti, P_WpPlus, 617, check)
      call createCurrent(P_s, P_sAnti, P_g, 280, check)
      call createCurrent(P_uAnti, P_Z, P_u, 1113, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_WPlus, 1152, check)
      call createCurrent(P_ePlus, P_nu_e, P_WpMinus, 1342, check)
      call createCurrent(P_A, P_GPlus, P_H, P_WMinus, 353, check)
      call createCurrent(P_d, P_dAnti, 1524, check)
      call createCurrent(P_H, P_A, P_WMinus, P_GPlus, 323, check)
      call createCurrent(P_A, P_Zp, P_g, P_g, 1653, check)
      call createCurrent(P_nu_e, P_ePlus, P_WMinus, 269, check)
      call createCurrent(P_H, P_G0, P_Z, 1147, check)
      call createCurrent(P_Z, P_nu_e, P_nu_eAnti, 369, check)
      call createCurrent(P_uAnti, P_d, P_WpPlus, 1096, check)
      call createCurrent(P_H, P_s, P_dAnti, 1399, check)
      call createCurrent(P_d, P_Zp, P_bAnti, 242, check)
      call createCurrent(P_Z, P_g, P_g, P_Zp, 1669, check)
      call createCurrent(P_g, P_WpPlus, P_g, P_WpMinus, 1591, check)
      call createCurrent(P_WpMinus, P_nu_tau, P_tauPlus, 488, check)
      call createCurrent(P_d, P_sAnti, P_H, 722, check)
      call createCurrent(P_d, P_GPlus, P_cAnti, 96, check)
      call createCurrent(P_G0, P_d, P_dAnti, 1155, check)
      call createCurrent(P_bAnti, P_G0, P_b, 1433, check)
      call createCurrent(P_GPlus, P_G0, P_GMinus, P_G0, 641, check)
      call createCurrent(P_H, P_Z, P_G0, 1386, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_H, 1307, check)
      call createCurrent(P_WpPlus, P_nu_muAnti, P_eMinus, 336, check)
      call createCurrent(P_bAnti, P_Z, P_b, 1060, check)
      call createCurrent(P_G0, P_tauPlus, P_tauMinus, 342, check)
      call createCurrent(P_G0, P_g, P_G0, P_g, 1556, check)
      call createCurrent(P_tauMinus, P_muPlus, P_Zp, 905, check)
      call createCurrent(P_Z, P_GPlus, P_Z, P_GMinus, 553, check)
      call createCurrent(P_s, P_GPlus, P_uAnti, 351, check)
      call createCurrent(P_tauPlus, P_nu_tau, P_WpMinus, 909, check)
      call createCurrent(P_u, P_Zp, P_tAnti, 1011, check)
      call createCurrent(P_H, P_muPlus, P_muMinus, 1495, check)
      call createCurrent(P_WPlus, P_WMinus, 1506, check)
      call createCurrent(P_G0, P_Z, P_WMinus, P_GPlus, 983, check)
      call createCurrent(P_Z, P_nu_tauAnti, P_nu_tau, 16, check)
      call createCurrent(P_dAnti, P_WpMinus, P_u, 520, check)
      call createCurrent(P_muMinus, P_muPlus, P_Zp, 718, check)
      call createCurrent(P_A, P_g, P_Zp, P_g, 1634, check)
      call createCurrent(P_u, P_Zp, P_cAnti, 406, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_Zp, 612, check)
      call createCurrent(P_A, P_WPlus, P_GMinus, P_H, 963, check)
      call createCurrent(P_A, P_A, P_GMinus, P_GPlus, 188, check)
      call createCurrent(P_tauMinus, P_WpPlus, P_nu_eAnti, 76, check)
      call createCurrent(P_muPlus, P_A, P_muMinus, 545, check)
      call createCurrent(P_WMinus, P_A, P_G0, P_GPlus, 1339, check)
      call createCurrent(P_G0, P_GMinus, P_WPlus, P_A, 170, check)
      call createCurrent(P_GPlus, P_A, P_A, P_GMinus, 455, check)
      call createCurrent(P_eMinus, P_GPlus, P_nu_eAnti, 984, check)
      call createCurrent(P_Zp, P_g, P_g, P_g, 1592, check)
      call createCurrent(P_Zp, P_s, P_bAnti, 1170, check)
      call createCurrent(P_ghWp, P_Z, P_ghWpAnti, 219, check)
      call createCurrent(P_d, P_G0, P_dAnti, 1251, check)
      call createCurrent(P_s, P_WPlus, P_cAnti, 594, check)
      call createCurrent(P_dAnti, P_WMinus, P_u, 94, check)
      call createCurrent(P_g, P_WMinus, P_g, P_WPlus, 1673, check)
      call createCurrent(P_WpPlus, P_uAnti, P_d, 1175, check)
      call createCurrent(P_Zp, P_tAnti, P_u, 1431, check)
      call createCurrent(P_tAnti, P_Zp, P_t, 886, check)
      call createCurrent(P_ghWpAnti, P_A, P_ghWp, 255, check)
      call createCurrent(P_G0, P_GMinus, P_Z, P_WPlus, 993, check)
      call createCurrent(P_d, P_cAnti, P_WPlus, 427, check)
      call createCurrent(P_g, P_g, P_WpPlus, P_WMinus, 1568, check)
      call createCurrent(P_muPlus, P_nu_tau, P_WpMinus, 25, check)
      call createCurrent(P_muPlus, P_nu_mu, P_WpMinus, 1226, check)
      call createCurrent(P_GPlus, P_g, P_GMinus, P_g, 1575, check)
      call createCurrent(P_A, P_Z, P_WMinus, P_WPlus, 374, check)
      call createCurrent(P_muPlus, P_H, P_muMinus, 1397, check)
      call createCurrent(P_A, P_s, P_sAnti, 853, check)
      call createCurrent(P_WMinus, P_A, P_WPlus, P_Z, 1129, check)
      call createCurrent(P_Zp, P_tauMinus, P_tauPlus, 401, check)
      call createCurrent(P_WMinus, P_H, P_GPlus, 470, check)
      call createCurrent(P_H, P_d, P_sAnti, 1102, check)
      call createCurrent(P_A, P_WMinus, P_Z, P_WPlus, 543, check)
      call createCurrent(P_A, P_H, P_WPlus, P_GMinus, 162, check)
      call createCurrent(P_d, P_g, P_dAnti, 18, check)
      call createCurrent(P_g, P_t, P_tAnti, 1354, check)
      call createCurrent(P_G0, P_Z, P_G0, P_Z, 367, check)
      call createCurrent(P_t, P_tAnti, 1502, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghZ, 133, check)
      call createCurrent(P_sAnti, P_WMinus, P_u, 547, check)
      call createCurrent(P_b, P_bAnti, P_Zp, 288, check)
      call createCurrent(P_nu_mu, P_nu_muAnti, 1535, check)
      call createCurrent(P_GMinus, P_GMinus, P_GPlus, P_GPlus, 1056, check)
      call createCurrent(P_GMinus, P_A, P_WPlus, 331, check)
      call createCurrent(P_eMinus, P_tauPlus, P_Zp, 17, check)
      call createCurrent(P_A, P_G0, P_WPlus, P_GMinus, 483, check)
      call createCurrent(P_GMinus, P_H, P_WPlus, P_A, 1157, check)
      call createCurrent(P_u, P_uAnti, P_Z, 393, check)
      call createCurrent(P_GPlus, P_H, P_Z, P_WMinus, 1160, check)
      call createCurrent(P_nu_eAnti, P_nu_e, P_Z, 776, check)
      call createCurrent(P_t, P_bAnti, P_WMinus, 52, check)
      call createCurrent(P_ghWpAnti, P_H, P_ghWp, 1111, check)
      call createCurrent(P_uAnti, P_WpPlus, P_d, 1294, check)
      call createCurrent(P_g, P_b, P_bAnti, 491, check)
      call createCurrent(P_A, P_b, P_bAnti, 1363, check)
      call createCurrent(P_g, P_g, P_H, P_H, 1547, check)
      call createCurrent(P_WpPlus, P_s, P_tAnti, 423, check)
      call createCurrent(P_c, P_H, P_cAnti, 926, check)
      call createCurrent(P_A, P_Z, P_WPlus, P_WMinus, 119, check)
      call createCurrent(P_GMinus, P_nu_tau, P_tauPlus, 809, check)
      call createCurrent(P_tAnti, P_Zp, P_c, 1052, check)
      call createCurrent(P_A, P_WPlus, P_G0, P_GMinus, 216, check)
      call createCurrent(P_GMinus, P_u, P_sAnti, 59, check)
      call createCurrent(P_uAnti, P_Zp, P_t, 988, check)
      call createCurrent(P_ePlus, P_eMinus, P_H, 889, check)
      call createCurrent(P_g, P_Zp, P_g, 1542, check)
      call createCurrent(P_WPlus, P_WMinus, P_WMinus, P_WPlus, 716, check)
      call createCurrent(P_d, P_H, P_dAnti, 1283, check)
      call createCurrent(P_g, P_GPlus, P_GMinus, P_g, 1583, check)
      call createCurrent(P_WMinus, P_WPlus, P_GPlus, P_GMinus, 153, check)
      call createCurrent(P_sAnti, P_s, P_G0, 1304, check)
      call createCurrent(P_WpMinus, P_sAnti, P_t, 261, check)
      call createCurrent(P_u, P_G0, P_uAnti, 1402, check)
      call createCurrent(P_H, P_A, P_GMinus, P_WPlus, 467, check)
      call createCurrent(P_Zp, P_uAnti, P_u, 1266, check)
      call createCurrent(P_WpPlus, P_tauMinus, P_nu_tauAnti, 601, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_H, 1299, check)
      call createCurrent(P_G0, P_sAnti, P_s, 190, check)
      call createCurrent(P_GMinus, P_WPlus, P_H, 606, check)
      call createCurrent(P_H, P_t, P_tAnti, 1085, check)
      call createCurrent(P_muPlus, P_WpMinus, P_nu_tau, 1319, check)
      call createCurrent(P_ghWmAnti, P_G0, P_ghWm, 218, check)
      call createCurrent(P_WPlus, P_A, P_WMinus, 647, check)
      call createCurrent(P_eMinus, P_ePlus, P_A, 436, check)
      call createCurrent(P_Z, P_WMinus, P_GPlus, P_H, 1177, check)
      call createCurrent(P_WpMinus, P_ePlus, P_nu_tau, 1117, check)
      call createCurrent(P_GMinus, P_WPlus, P_A, P_G0, 75, check)
      call createCurrent(P_GPlus, P_GMinus, P_g, P_g, 1658, check)
      call createCurrent(P_Zp, P_sAnti, P_s, 866, check)
      call createCurrent(P_Zp, P_t, P_uAnti, 1489, check)
      call createCurrent(P_d, P_GPlus, P_uAnti, 827, check)
      call createCurrent(P_H, P_Z, P_WMinus, P_GPlus, 175, check)
      call createCurrent(P_Z, P_GMinus, P_Z, P_GPlus, 1481, check)
      call createCurrent(P_GMinus, P_GPlus, P_Z, 184, check)
      call createCurrent(P_WMinus, P_Z, P_H, P_GPlus, 1045, check)
      call createCurrent(P_c, P_dAnti, P_WpMinus, 1298, check)
      call createCurrent(P_WPlus, P_A, P_GMinus, 997, check)
      call createCurrent(P_WPlus, P_Z, P_GMinus, P_H, 77, check)
      call createCurrent(P_WMinus, P_WPlus, P_WMinus, P_WPlus, 896, check)
      call createCurrent(P_GPlus, P_G0, P_WMinus, P_Z, 1193, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_WPlus, 37, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_GMinus, 1017, check)
      call createCurrent(P_Z, P_eMinus, P_ePlus, 1047, check)
      call createCurrent(P_g, P_g, P_g, P_Z, 1561, check)
      call createCurrent(P_muPlus, P_Zp, P_eMinus, 851, check)
      call createCurrent(P_ghWm, P_A, P_ghWmAnti, 318, check)
      call createCurrent(P_G0, P_GPlus, P_WMinus, P_Z, 741, check)
      call createCurrent(P_WpMinus, P_dAnti, P_c, 1209, check)
      call createCurrent(P_Z, P_WPlus, P_G0, P_GMinus, 1099, check)
      call createCurrent(P_muPlus, P_GMinus, P_nu_mu, 1125, check)
      call createCurrent(P_Z, P_GMinus, P_WPlus, P_H, 1114, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_GMinus, 1087, check)
      call createCurrent(P_nu_tau, P_tauPlus, P_WpMinus, 358, check)
      call createCurrent(P_d, P_WpPlus, P_cAnti, 10, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_G0, 925, check)
      call createCurrent(P_c, P_WpMinus, P_sAnti, 1260, check)
      call createCurrent(P_GMinus, P_WPlus, P_A, 681, check)
      call createCurrent(P_GMinus, P_A, P_G0, P_WPlus, 935, check)
      call createCurrent(P_tauPlus, P_tauMinus, 1525, check)
      call createCurrent(P_c, P_Z, P_cAnti, 962, check)
      call createCurrent(P_g, P_H, P_g, P_H, 1647, check)
      call createCurrent(P_H, P_b, P_bAnti, 438, check)
      call createCurrent(P_G0, P_GMinus, P_WPlus, P_Z, 258, check)
      call createCurrent(P_WpMinus, P_g, P_WPlus, P_g, 1681, check)
      call createCurrent(P_WMinus, P_u, P_sAnti, 1393, check)
      call createCurrent(P_g, P_g, 1526, check)
      call createCurrent(P_Z, P_Z, P_H, 1140, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_G0, 800, check)
      call createCurrent(P_WPlus, P_GMinus, P_H, 610, check)
      call createCurrent(P_WMinus, P_H, P_H, P_WPlus, 531, check)
      call createCurrent(P_WPlus, P_nu_eAnti, P_eMinus, 281, check)
      call createCurrent(P_WPlus, P_A, P_G0, P_GMinus, 1441, check)
      call createCurrent(P_A, P_WMinus, P_H, P_GPlus, 1172, check)
      call createCurrent(P_g, P_g, P_g, P_Zp, 1633, check)
      call createCurrent(P_Zp, P_muMinus, P_ePlus, 873, check)
      call createCurrent(P_WPlus, P_ghA, P_ghWpAnti, 146, check)
      call createCurrent(P_WMinus, P_WPlus, P_A, P_A, 458, check)
      call createCurrent(P_Zp, P_muPlus, P_muMinus, 602, check)
      call createCurrent(P_u, P_uAnti, P_g, 1090, check)
      call createCurrent(P_g, P_g, P_Z, P_Z, 1597, check)
      call createCurrent(P_nu_tauAnti, P_eMinus, P_WpPlus, 1452, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_ghA, 555, check)
      call createCurrent(P_GPlus, P_H, P_A, P_WMinus, 382, check)
      call createCurrent(P_ePlus, P_nu_e, P_GMinus, 164, check)
      call createCurrent(P_tauPlus, P_H, P_tauMinus, 1171, check)
      call createCurrent(P_A, P_G0, P_WMinus, P_GPlus, 591, check)
      call createCurrent(P_g, P_g, P_Zp, P_Z, 1636, check)
      call createCurrent(P_Z, P_A, P_GPlus, P_GMinus, 1061, check)
      call createCurrent(P_u, P_g, P_uAnti, 788, check)
      call createCurrent(P_GPlus, P_G0, P_Z, P_WMinus, 62, check)
      call createCurrent(P_tAnti, P_u, P_Zp, 682, check)
      call createCurrent(P_dAnti, P_c, P_GMinus, 163, check)
      call createCurrent(P_H, P_WPlus, P_GMinus, 603, check)
      call createCurrent(P_muMinus, P_WpPlus, P_nu_muAnti, 835, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_H, 1290, check)
      call createCurrent(P_s, P_tAnti, P_WpPlus, 430, check)
      call createCurrent(P_nu_tauAnti, P_GPlus, P_tauMinus, 195, check)
      call createCurrent(P_A, P_WPlus, P_Z, P_WMinus, 1139, check)
      call createCurrent(P_ePlus, P_eMinus, P_A, 475, check)
      call createCurrent(P_Zp, P_bAnti, P_s, 564, check)
      call createCurrent(P_GPlus, P_g, P_g, P_GMinus, 1539, check)
      call createCurrent(P_H, P_WMinus, P_GPlus, P_Z, 1496, check)
      call createCurrent(P_WpPlus, P_tauMinus, P_nu_eAnti, 642, check)
      call createCurrent(P_ghZAnti, P_H, P_ghZ, 486, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_H, 1343, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghAAnti, 1158, check)
      call createCurrent(P_muMinus, P_nu_muAnti, P_GPlus, 250, check)
      call createCurrent(P_H, P_Z, P_Z, P_H, 39, check)
      call createCurrent(P_H, P_GMinus, P_WPlus, 84, check)
      call createCurrent(P_WPlus, P_G0, P_GMinus, 1349, check)
      call createCurrent(P_WPlus, P_GMinus, P_G0, P_Z, 537, check)
      call createCurrent(P_nu_tau, P_WpMinus, P_tauPlus, 99, check)
      call createCurrent(P_d, P_G0, P_sAnti, 1345, check)
      call createCurrent(P_t, P_tAnti, P_A, 33, check)
      call createCurrent(P_A, P_GMinus, P_WPlus, P_H, 752, check)
      call createCurrent(P_H, P_ghWpAnti, P_ghWp, 1189, check)
      call createCurrent(P_H, P_tauPlus, P_tauMinus, 44, check)
      call createCurrent(P_WMinus, P_Z, P_GPlus, P_G0, 519, check)
      call createCurrent(P_GPlus, P_A, P_GMinus, P_A, 1259, check)
      call createCurrent(P_H, P_GMinus, P_WPlus, P_A, 1166, check)
      call createCurrent(P_g, P_Z, P_g, P_Z, 1676, check)
      call createCurrent(P_GPlus, P_Z, P_Z, P_GMinus, 180, check)
      call createCurrent(P_t, P_tAnti, P_G0, 839, check)
      call createCurrent(P_dAnti, P_WpMinus, P_t, 1423, check)
      call createCurrent(P_WMinus, P_WPlus, P_Z, 1128, check)
      call createCurrent(P_d, P_WPlus, P_uAnti, 934, check)
      call createCurrent(P_dAnti, P_u, P_GMinus, 651, check)
      call createCurrent(P_Zp, P_muMinus, P_muPlus, 892, check)
      call createCurrent(P_g, P_Zp, P_g, P_Z, 1582, check)
      call createCurrent(P_cAnti, P_s, P_WpPlus, 1466, check)
      call createCurrent(P_nu_mu, P_ePlus, P_WpMinus, 529, check)
      call createCurrent(P_GPlus, P_G0, P_A, P_WMinus, 614, check)
      call createCurrent(P_G0, P_WMinus, P_G0, P_WPlus, 1288, check)
      call createCurrent(P_WMinus, P_nu_mu, P_muPlus, 1476, check)
      call createCurrent(P_GPlus, P_cAnti, P_d, 946, check)
      call createCurrent(P_WPlus, P_Z, P_G0, P_GMinus, 324, check)
      call createCurrent(P_WMinus, P_G0, P_GPlus, 1083, check)
      call createCurrent(P_H, P_ghZAnti, P_ghZ, 310, check)
      call createCurrent(P_G0, P_eMinus, P_ePlus, 992, check)
      call createCurrent(P_H, P_GPlus, P_WMinus, P_Z, 1077, check)
      call createCurrent(P_WMinus, P_WPlus, P_Z, P_Z, 504, check)
      call createCurrent(P_ePlus, P_Zp, P_tauMinus, 1375, check)
      call createCurrent(P_u, P_dAnti, P_WMinus, 589, check)
      call createCurrent(P_tAnti, P_GPlus, P_b, 501, check)
      call createCurrent(P_Z, P_Z, P_g, P_g, 1576, check)
      call createCurrent(P_s, P_A, P_sAnti, 1206, check)
      call createCurrent(P_s, P_WpPlus, P_tAnti, 645, check)
      call createCurrent(P_G0, P_WMinus, P_Z, P_GPlus, 224, check)
      call createCurrent(P_muPlus, P_muMinus, P_G0, 1332, check)
      call createCurrent(P_nu_muAnti, P_WpPlus, P_eMinus, 903, check)
      call createCurrent(P_G0, P_H, P_Z, 440, check)
      call createCurrent(P_d, P_cAnti, P_WpPlus, 742, check)
      call createCurrent(P_H, P_H, P_WMinus, P_WPlus, 73, check)
      call createCurrent(P_GMinus, P_dAnti, P_c, 481, check)
      call createCurrent(P_dAnti, P_s, P_G0, 550, check)
      call createCurrent(P_WPlus, P_H, P_GMinus, P_Z, 1413, check)
      call createCurrent(P_G0, P_g, P_g, P_G0, 1566, check)
      call createCurrent(P_cAnti, P_A, P_c, 1358, check)
      call createCurrent(P_g, P_g, P_H, 1618, check)
      call createCurrent(P_muPlus, P_muMinus, P_H, 798, check)
      call createCurrent(P_WPlus, P_G0, P_GMinus, P_Z, 285, check)
      call createCurrent(P_tauPlus, P_G0, P_tauMinus, 1103, check)
      call createCurrent(P_tauMinus, P_WPlus, P_nu_tauAnti, 1221, check)
      call createCurrent(P_A, P_GPlus, P_WMinus, P_G0, 1352, check)
      call createCurrent(P_WMinus, P_ghZAnti, P_ghWp, 239, check)
      call createCurrent(P_nu_e, P_nu_eAnti, P_Z, 270, check)
      call createCurrent(P_GMinus, P_WPlus, P_Z, P_H, 347, check)
      call createCurrent(P_muMinus, P_muPlus, 1508, check)
      call createCurrent(P_uAnti, P_Zp, P_c, 785, check)
      call createCurrent(P_Z, P_nu_muAnti, P_nu_mu, 1364, check)
      call createCurrent(P_bAnti, P_b, P_G0, 1039, check)
      call createCurrent(P_g, P_g, P_WpPlus, P_WpMinus, 1549, check)
      call createCurrent(P_g, P_GMinus, P_GPlus, P_g, 1642, check)
      call createCurrent(P_Z, P_nu_tau, P_nu_tauAnti, 463, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghZ, 1053, check)
      call createCurrent(P_WPlus, P_nu_muAnti, P_muMinus, 1134, check)
      call createCurrent(P_muMinus, P_muPlus, P_A, 352, check)
      call createCurrent(P_A, P_WMinus, P_GPlus, P_G0, 1455, check)
      call createCurrent(P_WMinus, P_c, P_sAnti, 228, check)
      call createCurrent(P_sAnti, P_u, P_GMinus, 1169, check)
      call createCurrent(P_GMinus, P_WPlus, P_H, P_A, 12, check)
      call createCurrent(P_Z, P_GPlus, P_WMinus, P_G0, 1104, check)
      call createCurrent(P_G0, P_A, P_WMinus, P_GPlus, 632, check)
      call createCurrent(P_b, P_bAnti, P_G0, 1370, check)
      call createCurrent(P_A, P_WPlus, P_WMinus, 750, check)
      call createCurrent(P_tauPlus, P_A, P_tauMinus, 1424, check)
      call createCurrent(P_Z, P_Z, P_GPlus, P_GMinus, 339, check)
      call createCurrent(P_sAnti, P_t, P_WpMinus, 477, check)
      call createCurrent(P_H, P_sAnti, P_s, 265, check)
      call createCurrent(P_GMinus, P_Z, P_GPlus, P_A, 206, check)
      call createCurrent(P_bAnti, P_WMinus, P_t, 913, check)
      call createCurrent(P_WpMinus, P_sAnti, P_u, 252, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_ghA, 391, check)
      call createCurrent(P_WPlus, P_A, P_WMinus, P_A, 1106, check)
      call createCurrent(P_A, P_GPlus, P_WMinus, 1079, check)
      call createCurrent(P_WpMinus, P_nu_mu, P_tauPlus, 828, check)
      call createCurrent(P_u, P_tAnti, P_Zp, 1448, check)
      call createCurrent(P_ghGAnti, P_g, P_ghG, 172, check)
      call createCurrent(P_s, P_cAnti, P_WPlus, 936, check)
      call createCurrent(P_A, P_GMinus, P_WPlus, P_G0, 394, check)
      call createCurrent(P_A, P_WMinus, P_WPlus, 97, check)
      call createCurrent(P_H, P_WMinus, P_GPlus, 1151, check)
      call createCurrent(P_muPlus, P_WpMinus, P_nu_mu, 291, check)
      call createCurrent(P_WpPlus, P_b, P_cAnti, 1219, check)
      call createCurrent(P_Z, P_Z, P_WPlus, P_WMinus, 1181, check)
      call createCurrent(P_nu_eAnti, P_nu_e, 1528, check)
      call createCurrent(P_WPlus, P_b, P_tAnti, 1215, check)
      call createCurrent(P_A, P_GMinus, P_GPlus, P_A, 1176, check)
      call createCurrent(P_ghA, P_GPlus, P_ghWpAnti, 456, check)
      call createCurrent(P_WPlus, P_ghWm, P_ghZAnti, 251, check)
      call createCurrent(P_G0, P_Z, 1531, check)
      call createCurrent(P_WMinus, P_Z, P_A, P_WPlus, 273, check)
      call createCurrent(P_WPlus, P_WMinus, P_g, P_g, 1657, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_ghZ, 947, check)
      call createCurrent(P_Z, P_g, P_g, P_Z, 1545, check)
      call createCurrent(P_A, P_WPlus, P_WMinus, P_A, 829, check)
      call createCurrent(P_WPlus, P_uAnti, P_s, 1230, check)
      call createCurrent(P_Z, P_GMinus, P_WPlus, P_G0, 907, check)
      call createCurrent(P_GPlus, P_WMinus, P_WPlus, P_GMinus, 432, check)
      call createCurrent(P_GMinus, P_ghA, P_ghWmAnti, 237, check)
      call createCurrent(P_G0, P_bAnti, P_b, 507, check)
      call createCurrent(P_uAnti, P_b, P_WpPlus, 558, check)
      call createCurrent(P_Z, P_WPlus, P_WMinus, P_A, 679, check)
      call createCurrent(P_sAnti, P_WpMinus, P_c, 113, check)
      call createCurrent(P_G0, P_ghWp, P_ghWpAnti, 482, check)
      call createCurrent(P_GMinus, P_tauPlus, P_nu_tau, 411, check)
      call createCurrent(P_WPlus, P_WMinus, P_A, P_Z, 652, check)
      call createCurrent(P_muMinus, P_nu_muAnti, P_WpPlus, 1167, check)
      call createCurrent(P_Zp, P_muPlus, P_eMinus, 825, check)
      call createCurrent(P_WPlus, P_Z, P_GMinus, P_G0, 542, check)
      call createCurrent(P_t, P_WpMinus, P_dAnti, 637, check)
      call createCurrent(P_G0, P_GPlus, P_GMinus, P_G0, 428, check)
      call createCurrent(P_uAnti, P_s, P_GPlus, 457, check)
      call createCurrent(P_WMinus, P_A, P_A, P_WPlus, 977, check)
      call createCurrent(P_WPlus, P_WMinus, P_Z, P_A, 1143, check)
      call createCurrent(P_g, P_A, P_g, P_Z, 1660, check)
      call createCurrent(P_WPlus, P_tAnti, P_b, 1372, check)
      call createCurrent(P_nu_tauAnti, P_nu_tau, 1527, check)
      call createCurrent(P_nu_eAnti, P_WPlus, P_eMinus, 301, check)
      call createCurrent(P_Z, P_WMinus, P_Z, P_WPlus, 565, check)
      call createCurrent(P_A, P_g, P_g, P_Z, 1622, check)
      call createCurrent(P_nu_eAnti, P_WpPlus, P_eMinus, 538, check)
      call createCurrent(P_nu_tauAnti, P_nu_tau, P_Z, 140, check)
      call createCurrent(P_g, P_g, P_Zp, P_A, 1617, check)
      call createCurrent(P_tAnti, P_WPlus, P_b, 1444, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_A, 739, check)
      call createCurrent(P_GMinus, P_G0, P_WPlus, P_A, 95, check)
      call createCurrent(P_Z, P_u, P_uAnti, 1064, check)
      call createCurrent(P_H, P_g, P_g, P_H, 1632, check)
      call createCurrent(P_Zp, P_g, P_Zp, P_g, 1640, check)
      call createCurrent(P_Z, P_WPlus, P_WMinus, 1469, check)
      call createCurrent(P_Z, P_nu_mu, P_nu_muAnti, 1029, check)
      call createCurrent(P_GPlus, P_H, P_WMinus, P_A, 810, check)
      call createCurrent(P_u, P_sAnti, P_GMinus, 736, check)
      call createCurrent(P_WpPlus, P_nu_eAnti, P_tauMinus, 199, check)
      call createCurrent(P_WPlus, P_uAnti, P_d, 484, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghZAnti, 546, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Z, 362, check)
      call createCurrent(P_GPlus, P_GMinus, P_Z, P_Z, 933, check)
      call createCurrent(P_Z, P_g, P_g, P_A, 1672, check)
      call createCurrent(P_bAnti, P_t, P_WpMinus, 468, check)
      call createCurrent(P_H, P_GPlus, P_A, P_WMinus, 314, check)
      call createCurrent(P_uAnti, P_A, P_u, 451, check)
      call createCurrent(P_g, P_g, P_Zp, P_Zp, 1596, check)
      call createCurrent(P_WMinus, P_ghAAnti, P_ghWp, 247, check)
      call createCurrent(P_Z, P_A, P_GMinus, P_GPlus, 929, check)
      call createCurrent(P_Z, P_H, P_WMinus, P_GPlus, 1014, check)
      call createCurrent(P_WPlus, P_A, P_Z, P_WMinus, 1419, check)
      call createCurrent(P_g, P_g, P_A, P_g, 1605, check)
      call createCurrent(P_sAnti, P_c, P_GMinus, 1451, check)
      call createCurrent(P_A, P_GMinus, P_GPlus, P_Z, 1138, check)
      call createCurrent(P_WMinus, P_t, P_bAnti, 34, check)
      call createCurrent(P_u, P_dAnti, P_WpMinus, 1065, check)
      call createCurrent(P_WMinus, P_Z, P_GPlus, 125, check)
      call createCurrent(P_GPlus, P_GMinus, P_A, P_Z, 128, check)
      call createCurrent(P_eMinus, P_WpPlus, P_nu_eAnti, 780, check)
      call createCurrent(P_d, P_sAnti, P_G0, 355, check)
      call createCurrent(P_nu_muAnti, P_eMinus, P_WpPlus, 571, check)
      call createCurrent(P_H, P_g, P_g, 1613, check)
      call createCurrent(P_WPlus, P_GMinus, P_H, P_A, 425, check)
      call createCurrent(P_nu_e, P_nu_eAnti, 1529, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Z, 702, check)
      call createCurrent(P_nu_eAnti, P_Z, P_nu_e, 753, check)
      call createCurrent(P_b, P_Z, P_bAnti, 1276, check)
      call createCurrent(P_d, P_dAnti, P_G0, 498, check)
      call createCurrent(P_cAnti, P_WPlus, P_s, 238, check)
      call createCurrent(P_ghAAnti, P_WMinus, P_ghWp, 72, check)
      call createCurrent(P_g, P_WpPlus, P_g, P_WMinus, 1574, check)
      call createCurrent(P_GMinus, P_GPlus, P_A, P_A, 70, check)
      call createCurrent(P_d, P_uAnti, P_WPlus, 1054, check)
      call createCurrent(P_Zp, P_c, P_tAnti, 569, check)
      call createCurrent(P_GPlus, P_WPlus, P_GMinus, P_WMinus, 586, check)
      call createCurrent(P_tauPlus, P_WMinus, P_nu_tau, 751, check)
      call createCurrent(P_b, P_tAnti, P_WPlus, 1456, check)
      call createCurrent(P_g, P_g, P_WPlus, P_WMinus, 1656, check)
      call createCurrent(P_H, P_ghZ, P_ghZAnti, 371, check)
      call createCurrent(P_WMinus, P_g, P_g, P_WpPlus, 1602, check)
      call createCurrent(P_WMinus, P_GPlus, P_H, P_Z, 900, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_WMinus, 506, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghZAnti, 834, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_WMinus, 322, check)
      call createCurrent(P_tauPlus, P_WpMinus, P_nu_tau, 524, check)
      call createCurrent(P_H, P_Z, P_Z, 1482, check)
      call createCurrent(P_G0, P_b, P_bAnti, 1265, check)
      call createCurrent(P_GPlus, P_H, P_H, P_GMinus, 329, check)
      call createCurrent(P_H, P_g, P_H, P_g, 1560, check)
      call createCurrent(P_muPlus, P_WpMinus, P_nu_e, 755, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghZAnti, 211, check)
      call createCurrent(P_WMinus, P_nu_tau, P_tauPlus, 890, check)
      call createCurrent(P_muMinus, P_nu_eAnti, P_WpPlus, 167, check)
      call createCurrent(P_u, P_uAnti, P_Zp, 40, check)
      call createCurrent(P_s, P_bAnti, P_Zp, 176, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_WPlus, 695, check)
      call createCurrent(P_WPlus, P_WMinus, P_WPlus, P_WMinus, 831, check)
      call createCurrent(P_g, P_Z, P_Z, P_g, 1564, check)
      call createCurrent(P_nu_tau, P_Z, P_nu_tauAnti, 1385, check)
      call createCurrent(P_G0, P_dAnti, P_s, 678, check)
      call createCurrent(P_WPlus, P_Z, P_WMinus, P_A, 991, check)
      call createCurrent(P_b, P_WPlus, P_tAnti, 1404, check)
      call createCurrent(P_c, P_cAnti, P_H, 514, check)
      call createCurrent(P_bAnti, P_t, P_WMinus, 1254, check)
      call createCurrent(P_H, P_H, P_H, P_H, 340, check)
      call createCurrent(P_g, P_g, P_Zp, 1679, check)
      call createCurrent(P_Zp, P_s, P_dAnti, 203, check)
      call createCurrent(P_WPlus, P_eMinus, P_nu_eAnti, 527, check)
      call createCurrent(P_H, P_GPlus, P_WMinus, P_A, 615, check)
      call createCurrent(P_uAnti, P_WPlus, P_d, 623, check)
      call createCurrent(P_tauPlus, P_GMinus, P_nu_tau, 1081, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_WMinus, 817, check)
      call createCurrent(P_c, P_WMinus, P_dAnti, 186, check)
      call createCurrent(P_Zp, P_g, P_g, 1595, check)
      call createCurrent(P_nu_e, P_tauPlus, P_WpMinus, 1245, check)
      call createCurrent(P_WPlus, P_GMinus, P_A, P_H, 832, check)
      call createCurrent(P_GPlus, P_Z, P_WMinus, P_G0, 231, check)
      call createCurrent(P_nu_tauAnti, P_tauMinus, P_GPlus, 874, check)
      call createCurrent(P_WPlus, P_GMinus, P_Z, 1344, check)
      call createCurrent(P_A, P_ghWpAnti, P_ghWp, 220, check)
      call createCurrent(P_GPlus, P_d, P_uAnti, 243, check)
      call createCurrent(P_eMinus, P_ePlus, 1499, check)
      call createCurrent(P_GMinus, P_Z, P_WPlus, 354, check)
      call createCurrent(P_ghWp, P_H, P_ghWpAnti, 689, check)
      call createCurrent(P_dAnti, P_d, P_H, 137, check)
      call createCurrent(P_WpMinus, P_tauPlus, P_nu_e, 1005, check)
      call createCurrent(P_ghWm, P_Z, P_ghWmAnti, 89, check)
      call createCurrent(P_WPlus, P_H, P_GMinus, 580, check)
      call createCurrent(P_A, P_WMinus, P_WPlus, P_Z, 523, check)
      call createCurrent(P_Z, P_A, P_WMinus, P_WPlus, 1297, check)
      call createCurrent(P_d, P_Zp, P_sAnti, 1002, check)
      call createCurrent(P_tauMinus, P_ePlus, P_Zp, 1348, check)
      call createCurrent(P_eMinus, P_Zp, P_ePlus, 1487, check)
      call createCurrent(P_tauPlus, P_Zp, P_muMinus, 554, check)
      call createCurrent(P_Z, P_H, P_Z, 78, check)
      call createCurrent(P_A, P_tAnti, P_t, 967, check)
      call createCurrent(P_nu_mu, P_WpMinus, P_tauPlus, 989, check)
      call createCurrent(P_eMinus, P_WpPlus, P_nu_tauAnti, 1494, check)
      call createCurrent(P_G0, P_GPlus, P_WMinus, 1269, check)
      call createCurrent(P_nu_e, P_muPlus, P_WpMinus, 366, check)
      call createCurrent(P_GPlus, P_nu_tauAnti, P_tauMinus, 489, check)
      call createCurrent(P_GPlus, P_Z, P_GMinus, P_A, 1256, check)
      call createCurrent(P_Z, P_d, P_dAnti, 1165, check)
      call createCurrent(P_g, P_A, P_Zp, P_g, 1662, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_GMinus, 69, check)
      call createCurrent(P_tAnti, P_t, P_Zp, 806, check)
      call createCurrent(P_g, P_g, P_WpMinus, P_WpPlus, 1604, check)
      call createCurrent(P_b, P_A, P_bAnti, 1082, check)
      call createCurrent(P_WMinus, P_WPlus, P_WPlus, P_WMinus, 256, check)
      call createCurrent(P_GMinus, P_c, P_sAnti, 837, check)
      call createCurrent(P_WpMinus, P_c, P_sAnti, 1493, check)
      call createCurrent(P_WPlus, P_H, P_Z, P_GMinus, 405, check)
      call createCurrent(P_g, P_c, P_cAnti, 1369, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_A, 1141, check)
      call createCurrent(P_GMinus, P_H, P_GPlus, P_H, 1186, check)
      call createCurrent(P_WPlus, P_WMinus, P_GPlus, P_GMinus, 338, check)
      call createCurrent(P_cAnti, P_s, P_WPlus, 144, check)
      call createCurrent(P_bAnti, P_s, P_Zp, 28, check)
      call createCurrent(P_dAnti, P_G0, P_s, 295, check)
      call createCurrent(P_s, P_Zp, P_bAnti, 1394, check)
      call createCurrent(P_WPlus, P_GPlus, P_WMinus, P_GMinus, 1282, check)
      call createCurrent(P_WMinus, P_GPlus, P_G0, P_A, 510, check)
      call createCurrent(P_sAnti, P_d, P_G0, 732, check)
      call createCurrent(P_c, P_WpMinus, P_bAnti, 1121, check)
      call createCurrent(P_A, P_WPlus, P_H, P_GMinus, 1350, check)
      call createCurrent(P_Zp, P_c, P_uAnti, 604, check)
      call createCurrent(P_G0, P_GPlus, P_G0, P_GMinus, 165, check)
      call createCurrent(P_tauPlus, P_muMinus, P_Zp, 692, check)
      call createCurrent(P_GMinus, P_G0, P_Z, P_WPlus, 729, check)
      call createCurrent(P_WMinus, P_GPlus, 1504, check)
      call createCurrent(P_Zp, P_u, P_cAnti, 512, check)
      call createCurrent(P_Z, P_GMinus, P_GPlus, P_Z, 838, check)
      call createCurrent(P_g, P_sAnti, P_s, 1313, check)
      call createCurrent(P_ePlus, P_nu_e, P_WMinus, 572, check)
      call createCurrent(P_GMinus, P_WPlus, 1530, check)
      call createCurrent(P_WMinus, P_A, P_GPlus, 447, check)
      call createCurrent(P_eMinus, P_nu_eAnti, P_WpPlus, 1192, check)
      call createCurrent(P_A, P_t, P_tAnti, 277, check)
      call createCurrent(P_sAnti, P_GMinus, P_u, 1164, check)
      call createCurrent(P_b, P_G0, P_bAnti, 1420, check)
      call createCurrent(P_nu_tau, P_GMinus, P_tauPlus, 1302, check)
      call createCurrent(P_Z, P_WPlus, P_GMinus, 533, check)
      call createCurrent(P_ghWpAnti, P_Z, P_ghWp, 493, check)
      call createCurrent(P_Z, P_s, P_sAnti, 1335, check)
      call createCurrent(P_nu_tau, P_WMinus, P_tauPlus, 727, check)
      call createCurrent(P_WPlus, P_ghZAnti, P_ghWm, 1198, check)
      call createCurrent(P_GPlus, P_GMinus, P_GPlus, P_GMinus, 204, check)
      call createCurrent(P_GPlus, P_GMinus, P_A, P_A, 227, check)
      call createCurrent(P_sAnti, P_s, P_g, 775, check)
      call createCurrent(P_WPlus, P_GMinus, 1518, check)
      call createCurrent(P_WpMinus, P_WPlus, P_g, P_g, 1559, check)
      call createCurrent(P_A, P_g, P_Z, P_g, 1585, check)
      call createCurrent(P_WPlus, P_WPlus, P_WMinus, P_WMinus, 160, check)
      call createCurrent(P_cAnti, P_Zp, P_u, 744, check)
      call createCurrent(P_GPlus, P_WMinus, P_A, 311, check)
      call createCurrent(P_nu_eAnti, P_WpPlus, P_muMinus, 1300, check)
      call createCurrent(P_tAnti, P_t, P_g, 299, check)
      call createCurrent(P_GPlus, P_ghZ, P_ghWpAnti, 585, check)
      call createCurrent(P_s, P_dAnti, P_H, 849, check)
      call createCurrent(P_WpPlus, P_nu_tauAnti, P_tauMinus, 697, check)
      call createCurrent(P_H, P_Z, P_GPlus, P_WMinus, 1310, check)
      call createCurrent(P_A, P_GMinus, P_H, P_WPlus, 1389, check)
      call createCurrent(P_WMinus, P_ghWp, P_ghZAnti, 194, check)
      call createCurrent(P_GMinus, P_WPlus, P_GPlus, P_WMinus, 738, check)
      call createCurrent(P_eMinus, P_ePlus, P_G0, 961, check)
      call createCurrent(P_g, P_Z, P_g, P_Zp, 1650, check)
      call createCurrent(P_WPlus, P_GMinus, P_A, P_G0, 1377, check)
      call createCurrent(P_H, P_bAnti, P_b, 782, check)
      call createCurrent(P_GPlus, P_WMinus, P_G0, 770, check)
      call createCurrent(P_t, P_WpMinus, P_sAnti, 1463, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_H, 118, check)
      call createCurrent(P_GMinus, P_GPlus, P_Z, P_A, 1243, check)
      call createCurrent(P_uAnti, P_u, P_Z, 1220, check)
      call createCurrent(P_GMinus, P_G0, P_GPlus, P_G0, 1200, check)
      call createCurrent(P_tAnti, P_b, P_WpPlus, 1303, check)
      call createCurrent(P_GPlus, P_Z, P_H, P_WMinus, 608, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_GMinus, 274, check)
      call createCurrent(P_Z, P_WMinus, P_WPlus, P_Z, 344, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_ghA, 139, check)
      call createCurrent(P_GMinus, P_H, P_H, P_GPlus, 1442, check)
      call createCurrent(P_nu_mu, P_Z, P_nu_muAnti, 951, check)
      call createCurrent(P_WpPlus, P_cAnti, P_d, 1066, check)
      call createCurrent(P_GMinus, P_GPlus, P_GPlus, P_GMinus, 495, check)
      call createCurrent(P_sAnti, P_s, P_Zp, 1116, check)
      call createCurrent(P_u, P_WMinus, P_dAnti, 1388, check)
      call createCurrent(P_Z, P_WMinus, P_GPlus, 596, check)
      call createCurrent(P_ghG, P_g, P_ghGAnti, 7, check)
      call createCurrent(P_GPlus, P_Z, P_WMinus, P_H, 1231, check)
      call createCurrent(P_H, P_s, P_sAnti, 1257, check)
      call createCurrent(P_tauMinus, P_Z, P_tauPlus, 312, check)
      call createCurrent(P_A, P_g, P_g, P_A, 1600, check)
      call createCurrent(P_GMinus, P_nu_mu, P_muPlus, 916, check)
      call createCurrent(P_WPlus, P_WMinus, P_GMinus, P_GPlus, 14, check)
      call createCurrent(P_eMinus, P_ePlus, P_H, 496, check)
      call createCurrent(P_A, P_bAnti, P_b, 1207, check)
      call createCurrent(P_g, P_WpPlus, P_WpMinus, P_g, 1541, check)
      call createCurrent(P_ePlus, P_eMinus, 1514, check)
      call createCurrent(P_nu_tau, P_nu_tauAnti, P_Z, 872, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghA, 970, check)
      call createCurrent(P_Zp, P_g, P_Z, P_g, 1599, check)
      call createCurrent(P_g, P_Z, P_g, P_A, 1551, check)
      call createCurrent(P_ePlus, P_WpMinus, P_nu_mu, 399, check)
      call createCurrent(P_WpMinus, P_tauPlus, P_nu_mu, 377, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_GPlus, 841, check)
      call createCurrent(P_uAnti, P_GPlus, P_s, 1271, check)
      call createCurrent(P_Z, P_tauMinus, P_tauPlus, 372, check)
      call createCurrent(P_G0, P_H, P_H, P_G0, 392, check)
      call createCurrent(P_GMinus, P_H, P_GPlus, 914, check)
      call createCurrent(P_dAnti, P_d, P_Zp, 222, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_A, 390, check)
      call createCurrent(P_WMinus, P_WPlus, P_g, P_g, 1667, check)
      call createCurrent(P_Z, P_A, P_WPlus, P_WMinus, 408, check)
      call createCurrent(P_H, P_WMinus, P_A, P_GPlus, 620, check)
      call createCurrent(P_nu_tau, P_tauPlus, P_GMinus, 1497, check)
      call createCurrent(P_GMinus, P_A, P_WPlus, P_G0, 1295, check)
      call createCurrent(P_GPlus, P_uAnti, P_d, 549, check)
      call createCurrent(P_Zp, P_t, P_cAnti, 662, check)
      call createCurrent(P_G0, P_tauMinus, P_tauPlus, 386, check)
      call createCurrent(P_nu_muAnti, P_nu_mu, 1515, check)
      call createCurrent(P_WpMinus, P_t, P_dAnti, 1462, check)
      call createCurrent(P_G0, P_s, P_sAnti, 648, check)
      call createCurrent(P_Zp, P_eMinus, P_tauPlus, 1248, check)
      call createCurrent(P_Z, P_H, P_G0, 1436, check)
      call createCurrent(P_ghAAnti, P_WPlus, P_ghWm, 631, check)
      call createCurrent(P_nu_tau, P_nu_tauAnti, 1500, check)
      call createCurrent(P_tauPlus, P_nu_tau, P_WMinus, 193, check)
      call createCurrent(P_WpMinus, P_sAnti, P_c, 930, check)
      call createCurrent(P_WMinus, P_WPlus, P_G0, P_G0, 58, check)
      call createCurrent(P_Z, P_g, P_A, P_g, 1579, check)
      call createCurrent(P_tAnti, P_t, P_G0, 588, check)
      call createCurrent(P_WpMinus, P_g, P_g, P_WPlus, 1590, check)
      call createCurrent(P_G0, P_ghWmAnti, P_ghWm, 821, check)
      call createCurrent(P_Zp, P_u, P_tAnti, 1272, check)
      call createCurrent(P_s, P_G0, P_sAnti, 141, check)
      call createCurrent(P_g, P_g, P_WPlus, P_WpMinus, 1544, check)
      call createCurrent(P_GPlus, P_WMinus, P_H, P_Z, 1301, check)
      call createCurrent(P_GMinus, P_ghWp, P_ghZAnti, 609, check)
      call createCurrent(P_GPlus, P_WMinus, P_GMinus, P_WPlus, 1196, check)
      call createCurrent(P_tAnti, P_t, P_H, 1491, check)
      call createCurrent(P_Zp, P_tAnti, P_c, 1003, check)
      call createCurrent(P_nu_tauAnti, P_tauMinus, P_WPlus, 940, check)
      call createCurrent(P_tauPlus, P_eMinus, P_Zp, 578, check)
      call createCurrent(P_A, P_Z, P_GPlus, P_GMinus, 307, check)
      call createCurrent(P_t, P_bAnti, P_GMinus, 784, check)
      call createCurrent(P_c, P_uAnti, P_Zp, 1095, check)
      call createCurrent(P_Zp, P_tAnti, P_t, 4, check)
      call createCurrent(P_d, P_sAnti, P_Zp, 1100, check)
      call createCurrent(P_GPlus, P_G0, P_WMinus, 499, check)
      call createCurrent(P_c, P_cAnti, P_g, 650, check)
      call createCurrent(P_Zp, P_cAnti, P_c, 83, check)
      call createCurrent(P_H, P_H, P_G0, P_G0, 1498, check)
      call createCurrent(P_G0, P_WMinus, P_GPlus, P_Z, 1235, check)
      call createCurrent(P_A, P_WPlus, P_WMinus, P_Z, 1367, check)
      call createCurrent(P_H, P_WPlus, P_GMinus, P_Z, 1337, check)
      call createCurrent(P_Zp, P_muMinus, P_tauPlus, 1223, check)
      call createCurrent(P_G0, P_G0, P_H, P_H, 764, check)
      call createCurrent(P_tAnti, P_A, P_t, 660, check)
      call createCurrent(P_A, P_g, P_g, P_Zp, 1644, check)
      call createCurrent(P_c, P_WMinus, P_sAnti, 945, check)
      call createCurrent(P_u, P_Z, P_uAnti, 15, check)
      call createCurrent(P_g, P_GPlus, P_g, P_GMinus, 1677, check)
      call createCurrent(P_s, P_sAnti, P_A, 313, check)
      call createCurrent(P_t, P_tAnti, P_g, 1, check)
      call createCurrent(P_uAnti, P_s, P_WPlus, 836, check)
      call createCurrent(P_GPlus, P_ghA, P_ghWpAnti, 791, check)
      call createCurrent(P_bAnti, P_d, P_Zp, 1107, check)
      call createCurrent(P_Z, P_bAnti, P_b, 869, check)
      call createCurrent(P_sAnti, P_c, P_WpMinus, 1318, check)
      call createCurrent(P_G0, P_GPlus, P_Z, P_WMinus, 867, check)
      call createCurrent(P_G0, P_WPlus, P_GMinus, P_A, 1324, check)
      call createCurrent(P_g, P_WMinus, P_WpPlus, P_g, 1620, check)
      call createCurrent(P_WMinus, P_GPlus, P_H, P_A, 882, check)
      call createCurrent(P_Z, P_dAnti, P_d, 634, check)
      call createCurrent(P_b, P_cAnti, P_WpPlus, 332, check)
      call createCurrent(P_A, P_WMinus, P_A, P_WPlus, 407, check)
      call createCurrent(P_nu_tauAnti, P_WpPlus, P_muMinus, 161, check)
      call createCurrent(P_A, P_c, P_cAnti, 1185, check)
      call createCurrent(P_WMinus, P_Z, P_WPlus, 1486, check)
      call createCurrent(P_A, P_uAnti, P_u, 1105, check)
      call createCurrent(P_A, P_GPlus, P_GMinus, P_A, 685, check)
      call createCurrent(P_GPlus, P_Z, P_GMinus, 792, check)
      call createCurrent(P_WpPlus, P_nu_tauAnti, P_eMinus, 657, check)
      call createCurrent(P_GMinus, P_Z, P_GPlus, P_Z, 723, check)
      call createCurrent(P_Z, P_g, P_Z, P_g, 1552, check)
      call createCurrent(P_WpPlus, P_muMinus, P_nu_eAnti, 360, check)
      call createCurrent(P_GPlus, P_A, P_H, P_WMinus, 1091, check)
      call createCurrent(P_eMinus, P_nu_eAnti, P_WPlus, 389, check)
      call createCurrent(P_g, P_Z, P_Zp, P_g, 1664, check)
      call createCurrent(P_s, P_g, P_sAnti, 404, check)
      call createCurrent(P_G0, P_G0, P_Z, P_Z, 1119, check)
      call createCurrent(P_u, P_sAnti, P_WMinus, 364, check)
      call createCurrent(P_uAnti, P_Zp, P_u, 743, check)
      call createCurrent(P_Z, P_GMinus, P_WPlus, 719, check)
      call createCurrent(P_WpMinus, P_bAnti, P_t, 618, check)
      call createCurrent(P_A, P_g, P_g, P_g, 1543, check)
      call createCurrent(P_d, P_uAnti, P_WpPlus, 325, check)
      call createCurrent(P_Zp, P_dAnti, P_s, 1194, check)
      call createCurrent(P_nu_e, P_GMinus, P_ePlus, 942, check)
      call createCurrent(P_muMinus, P_muPlus, P_H, 859, check)
      call createCurrent(P_d, P_bAnti, P_Zp, 871, check)
      call createCurrent(P_dAnti, P_d, 1536, check)
      call createCurrent(P_GMinus, P_WPlus, P_Z, P_G0, 830, check)
      call createCurrent(P_s, P_sAnti, P_Z, 1069, check)
      call createCurrent(P_g, P_H, P_g, 1570, check)
      call createCurrent(P_H, P_GPlus, P_GMinus, P_H, 419, check)
      call createCurrent(P_Z, P_ghWm, P_ghWmAnti, 1078, check)
      call createCurrent(P_sAnti, P_Zp, P_b, 1390, check)
      call createCurrent(P_g, P_d, P_dAnti, 1168, check)
      call createCurrent(P_cAnti, P_g, P_c, 286, check)
      call createCurrent(P_A, P_cAnti, P_c, 92, check)
      call createCurrent(P_GMinus, P_Z, P_A, P_GPlus, 2, check)
      call createCurrent(P_WpPlus, P_g, P_g, P_WpMinus, 1626, check)
      call createCurrent(P_g, P_tAnti, P_t, 714, check)
      call createCurrent(P_s, P_dAnti, P_Zp, 1149, check)
      call createCurrent(P_WPlus, P_WMinus, P_G0, P_G0, 846, check)
      call createCurrent(P_H, P_GMinus, P_Z, P_WPlus, 1208, check)
      call createCurrent(P_d, P_uAnti, P_GPlus, 464, check)
      call createCurrent(P_g, P_WMinus, P_g, P_WpPlus, 1625, check)
      call createCurrent(P_H, P_GPlus, P_WMinus, 842, check)
      call createCurrent(P_H, P_tauMinus, P_tauPlus, 684, check)
      call createCurrent(P_t, P_g, P_tAnti, 999, check)
      call createCurrent(P_Z, P_ghWmAnti, P_ghWm, 55, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_GMinus, 897, check)
      call createCurrent(P_ghG, P_ghGAnti, P_g, 1136, check)
      call createCurrent(P_GMinus, P_ghZAnti, P_ghWp, 85, check)
      call createCurrent(P_WpMinus, P_nu_tau, P_muPlus, 1278, check)
      call createCurrent(P_H, P_GMinus, P_WPlus, P_Z, 636, check)
      call createCurrent(P_G0, P_WPlus, P_Z, P_GMinus, 567, check)
      call createCurrent(P_WPlus, P_A, P_A, P_WMinus, 633, check)
      call createCurrent(P_WMinus, P_WpPlus, P_g, P_g, 1641, check)
      call createCurrent(P_ghA, P_WPlus, P_ghWpAnti, 245, check)
      call createCurrent(P_nu_mu, P_WpMinus, P_ePlus, 1474, check)
      call createCurrent(P_G0, P_u, P_uAnti, 461, check)
      call createCurrent(P_muPlus, P_muMinus, 1517, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_A, 298, check)
      call createCurrent(P_WMinus, P_GPlus, P_Z, 570, check)
      call createCurrent(P_uAnti, P_c, P_Zp, 1281, check)
      call createCurrent(P_b, P_dAnti, P_Zp, 864, check)
      call createCurrent(P_uAnti, P_G0, P_u, 439, check)
      call createCurrent(P_A, P_A, P_GPlus, P_GMinus, 630, check)
      call createCurrent(P_dAnti, P_d, P_Z, 1073, check)
      call createCurrent(P_A, P_ghWmAnti, P_ghWm, 949, check)
      call createCurrent(P_Zp, P_ePlus, P_muMinus, 590, check)
      call createCurrent(P_sAnti, P_d, P_Zp, 975, check)
      call createCurrent(P_nu_mu, P_tauPlus, P_WpMinus, 1202, check)
      call createCurrent(P_bAnti, P_b, P_Zp, 1051, check)
      call createCurrent(P_muMinus, P_Zp, P_ePlus, 41, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghZ, 156, check)
      call createCurrent(P_WpPlus, P_eMinus, P_nu_eAnti, 1031, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_A, 271, check)
      call createCurrent(P_Z, P_G0, P_GPlus, P_WMinus, 1464, check)
      call createCurrent(P_H, P_H, P_g, P_g, 1589, check)
      call createCurrent(P_WpPlus, P_eMinus, P_nu_tauAnti, 348, check)
      call createCurrent(P_Z, P_b, P_bAnti, 574, check)
      call createCurrent(P_GMinus, P_G0, P_WPlus, P_Z, 1086, check)
      call createCurrent(P_t, P_tAnti, P_H, 673, check)
      call createCurrent(P_WPlus, P_G0, P_Z, P_GMinus, 1174, check)
      call createCurrent(P_Z, P_GMinus, P_G0, P_WPlus, 385, check)
      call createCurrent(P_nu_tauAnti, P_WpPlus, P_eMinus, 822, check)
      call createCurrent(P_GPlus, P_A, P_GMinus, 57, check)
      call createCurrent(P_WMinus, P_nu_e, P_ePlus, 441, check)
      call createCurrent(P_H, P_WMinus, P_H, P_WPlus, 1480, check)
      call createCurrent(P_g, P_u, P_uAnti, 860, check)
      call createCurrent(P_eMinus, P_A, P_ePlus, 794, check)
      call createCurrent(P_tAnti, P_WpPlus, P_s, 123, check)
      call createCurrent(P_nu_tauAnti, P_Z, P_nu_tau, 1321, check)
      call createCurrent(P_muMinus, P_WpPlus, P_nu_tauAnti, 1325, check)
      call createCurrent(P_Zp, P_Zp, 1511, check)
      call createCurrent(P_GPlus, P_GMinus, P_Z, 511, check)
      call createCurrent(P_GMinus, P_GPlus, P_H, 1016, check)
      call createCurrent(P_G0, P_GMinus, P_GPlus, P_G0, 471, check)
      call createCurrent(P_A, P_GMinus, P_A, P_GPlus, 368, check)
      call createCurrent(P_sAnti, P_s, P_A, 80, check)
      call createCurrent(P_tAnti, P_d, P_WpPlus, 263, check)
      call createCurrent(P_muPlus, P_tauMinus, P_Zp, 1379, check)
      call createCurrent(P_H, P_Z, P_H, P_Z, 79, check)
      call createCurrent(P_WpPlus, P_tAnti, P_b, 525, check)
      call createCurrent(P_WpPlus, P_uAnti, P_s, 1320, check)
      call createCurrent(P_eMinus, P_ePlus, P_Z, 1133, check)
      call createCurrent(P_G0, P_Z, P_GPlus, P_WMinus, 453, check)
      call createCurrent(P_G0, P_G0, P_WPlus, P_WMinus, 296, check)
      call createCurrent(P_GMinus, P_ePlus, P_nu_e, 178, check)
      call createCurrent(P_G0, P_A, P_GPlus, P_WMinus, 818, check)
      call createCurrent(P_WMinus, P_GPlus, P_Z, P_H, 1038, check)
      call createCurrent(P_Zp, P_Z, P_g, P_g, 1637, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_WPlus, 624, check)
      call createCurrent(P_WPlus, P_ghAAnti, P_ghWm, 1326, check)
      call createCurrent(P_b, P_uAnti, P_WpPlus, 1406, check)
      call createCurrent(P_cAnti, P_c, P_g, 1426, check)
      call createCurrent(P_GPlus, P_ghZAnti, P_ghWm, 289, check)
      call createCurrent(P_Zp, P_eMinus, P_muPlus, 462, check)
      call createCurrent(P_GMinus, P_G0, P_G0, P_GPlus, 0, check)
      call createCurrent(P_GMinus, P_sAnti, P_u, 856, check)
      call createCurrent(P_Zp, P_ePlus, P_eMinus, 840, check)
      call createCurrent(P_uAnti, P_GPlus, P_d, 1126, check)
      call createCurrent(P_u, P_GMinus, P_sAnti, 595, check)
      call createCurrent(P_A, P_g, P_A, P_g, 1611, check)
      call createCurrent(P_WMinus, P_H, P_GPlus, P_Z, 799, check)
      call createCurrent(P_A, P_sAnti, P_s, 208, check)
      call createCurrent(P_nu_mu, P_muPlus, P_WpMinus, 35, check)
      call createCurrent(P_Z, P_ghWp, P_ghWpAnti, 276, check)
      call createCurrent(P_d, P_WpPlus, P_uAnti, 155, check)
      call createCurrent(P_sAnti, P_u, P_WpMinus, 796, check)
      call createCurrent(P_d, P_dAnti, P_Z, 1353, check)
      call createCurrent(P_Zp, P_tauPlus, P_tauMinus, 763, check)
      call createCurrent(P_nu_e, P_WpMinus, P_tauPlus, 302, check)
      call createCurrent(P_WpMinus, P_tauPlus, P_nu_tau, 964, check)
      call createCurrent(P_dAnti, P_H, P_d, 1317, check)
      call createCurrent(P_u, P_H, P_uAnti, 1109, check)
      call createCurrent(P_tAnti, P_H, P_t, 1026, check)
      call createCurrent(P_WPlus, P_ghWm, P_ghAAnti, 236, check)
      call createCurrent(P_cAnti, P_s, P_GPlus, 693, check)
      call createCurrent(P_G0, P_A, P_GMinus, P_WPlus, 50, check)
      call createCurrent(P_Z, P_A, P_g, P_g, 1671, check)
      call createCurrent(P_WpMinus, P_ePlus, P_nu_e, 628, check)
      call createCurrent(P_GMinus, P_A, P_H, P_WPlus, 1330, check)
      call createCurrent(P_Z, P_GMinus, P_A, P_GPlus, 1228, check)
      call createCurrent(P_GMinus, P_u, P_dAnti, 703, check)
      call createCurrent(P_Z, P_ghWpAnti, P_ghWp, 132, check)
      call createCurrent(P_WpMinus, P_WpPlus, 1533, check)
      call createCurrent(P_GPlus, P_s, P_uAnti, 169, check)
      call createCurrent(P_WMinus, P_G0, P_WPlus, P_G0, 221, check)
      call createCurrent(P_cAnti, P_u, P_Zp, 793, check)
      call createCurrent(P_WPlus, P_Z, P_WMinus, P_Z, 978, check)
      call createCurrent(P_sAnti, P_G0, P_s, 1392, check)
      call createCurrent(P_GPlus, P_GMinus, P_Z, P_A, 1470, check)
      call createCurrent(P_ghGAnti, P_ghG, P_g, 1268, check)
      call createCurrent(P_nu_muAnti, P_muMinus, P_WpPlus, 1421, check)
      call createCurrent(P_cAnti, P_t, P_Zp, 958, check)
      call createCurrent(P_muMinus, P_Z, P_muPlus, 981, check)
      call createCurrent(P_G0, P_G0, P_WMinus, P_WPlus, 202, check)
      call createCurrent(P_b, P_Zp, P_sAnti, 476, check)
      call createCurrent(P_b, P_WpPlus, P_tAnti, 1315, check)
      call createCurrent(P_GMinus, P_c, P_dAnti, 701, check)
      call createCurrent(P_b, P_bAnti, P_A, 11, check)
      call createCurrent(P_c, P_bAnti, P_WpMinus, 740, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_ghZ, 845, check)
      call createCurrent(P_WMinus, P_GPlus, P_GMinus, P_WPlus, 142, check)
      call createCurrent(P_g, P_g, P_g, P_g, 544, check)
      call createCurrent(P_dAnti, P_WpMinus, P_c, 522, check)
      call createCurrent(P_tAnti, P_b, P_WPlus, 1148, check)
      call createCurrent(P_WpMinus, P_u, P_dAnti, 1453, check)
      call createCurrent(P_nu_eAnti, P_eMinus, P_WPlus, 994, check)
      call createCurrent(P_H, P_Z, P_WPlus, P_GMinus, 627, check)
      call createCurrent(P_g, P_WMinus, P_WPlus, P_g, 1578, check)
      call createCurrent(P_A, P_GPlus, P_Z, P_GMinus, 267, check)
      call createCurrent(P_Z, P_H, P_H, P_Z, 316, check)
      call createCurrent(P_ghZAnti, P_WMinus, P_ghWp, 847, check)
      call createCurrent(P_t, P_WMinus, P_bAnti, 1253, check)
      call createCurrent(P_WPlus, P_cAnti, P_d, 108, check)
      call createCurrent(P_GPlus, P_nu_muAnti, P_muMinus, 1488, check)
      call createCurrent(P_WpMinus, P_t, P_bAnti, 107, check)
      call createCurrent(P_H, P_d, P_dAnti, 335, check)
      call createCurrent(P_Zp, P_dAnti, P_b, 448, check)
      call createCurrent(P_Z, P_GMinus, P_H, P_WPlus, 625, check)
      call createCurrent(P_WpMinus, P_u, P_bAnti, 982, check)
      call createCurrent(P_tAnti, P_WpPlus, P_b, 708, check)
      call createCurrent(P_WMinus, P_ghWp, P_ghAAnti, 1234, check)
      call createCurrent(P_nu_eAnti, P_WpPlus, P_tauMinus, 500, check)
      call createCurrent(P_s, P_Zp, P_dAnti, 1351, check)
      call createCurrent(P_dAnti, P_Zp, P_s, 728, check)
      call createCurrent(P_dAnti, P_c, P_WpMinus, 1163, check)
      call createCurrent(P_WPlus, P_GMinus, P_Z, P_H, 521, check)
      call createCurrent(P_H, P_GMinus, P_H, P_GPlus, 145, check)
      call createCurrent(P_bAnti, P_c, P_WpMinus, 691, check)
      call createCurrent(P_A, P_GPlus, P_GMinus, 173, check)
      call createCurrent(P_WPlus, P_Z, P_GMinus, 226, check)
      call createCurrent(P_bAnti, P_A, P_b, 771, check)
      call createCurrent(P_bAnti, P_Zp, P_s, 100, check)
      call createCurrent(P_G0, P_t, P_tAnti, 121, check)
      call createCurrent(P_cAnti, P_c, P_G0, 980, check)
      call createCurrent(P_Zp, P_d, P_sAnti, 1032, check)
      call createCurrent(P_H, P_WMinus, P_GPlus, P_A, 444, check)
      call createCurrent(P_bAnti, P_g, P_b, 478, check)
      call createCurrent(P_WMinus, P_G0, P_Z, P_GPlus, 902, check)
      call createCurrent(P_GMinus, P_A, P_GPlus, 885, check)
      call createCurrent(P_muPlus, P_Zp, P_muMinus, 43, check)
      call createCurrent(P_GMinus, P_A, P_GPlus, P_A, 112, check)
      call createCurrent(P_muMinus, P_H, P_muPlus, 1067, check)
      call createCurrent(P_Zp, P_cAnti, P_t, 1360, check)
      call createCurrent(P_Zp, P_tauPlus, P_eMinus, 686, check)
      call createCurrent(P_GMinus, P_GPlus, P_GMinus, P_GPlus, 605, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghA, 876, check)
      call createCurrent(P_tauPlus, P_nu_mu, P_WpMinus, 1112, check)
      call createCurrent(P_g, P_uAnti, P_u, 1285, check)
      call createCurrent(P_dAnti, P_s, P_H, 948, check)
      call createCurrent(P_Z, P_H, P_Z, P_H, 1492, check)
      call createCurrent(P_muMinus, P_G0, P_muPlus, 939, check)
      call createCurrent(P_Zp, P_ePlus, P_tauMinus, 1408, check)
      call createCurrent(P_WpMinus, P_bAnti, P_u, 1028, check)
      call createCurrent(P_Z, P_Zp, P_g, P_g, 1630, check)
      call createCurrent(P_H, P_ghWmAnti, P_ghWm, 1430, check)
      call createCurrent(P_nu_mu, P_GMinus, P_muPlus, 1092, check)
      call createCurrent(P_WpMinus, P_muPlus, P_nu_mu, 901, check)
      call createCurrent(P_GMinus, P_Z, P_WPlus, P_H, 86, check)
      call createCurrent(P_WMinus, P_A, P_GPlus, P_H, 1446, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_WMinus, 1242, check)
      call createCurrent(P_G0, P_Z, P_GMinus, P_WPlus, 1094, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_WPlus, 346, check)
      call createCurrent(P_ghWmAnti, P_Z, P_ghWm, 1236, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_G0, 171, check)
      call createCurrent(P_g, P_Zp, P_Zp, P_g, 1610, check)
      call createCurrent(P_g, P_Z, P_A, P_g, 1614, check)
      call createCurrent(P_muPlus, P_Z, P_muMinus, 333, check)
      call createCurrent(P_WpPlus, P_nu_eAnti, P_eMinus, 616, check)
      call createCurrent(P_dAnti, P_GMinus, P_c, 452, check)
      call createCurrent(P_c, P_tAnti, P_Zp, 465, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_ghZ, 541, check)
      call createCurrent(P_Zp, P_b, P_bAnti, 345, check)
      call createCurrent(P_Zp, P_Zp, P_g, P_g, 1588, check)
      call createCurrent(P_GMinus, P_H, P_WPlus, P_Z, 1183, check)
      call createCurrent(P_Z, P_cAnti, P_c, 613, check)
      call createCurrent(P_muPlus, P_G0, P_muMinus, 5, check)
      call createCurrent(P_nu_tauAnti, P_WPlus, P_tauMinus, 259, check)
      call createCurrent(P_H, P_G0, P_G0, P_H, 1216, check)
      call createCurrent(P_nu_mu, P_WpMinus, P_muPlus, 460, check)
      call createCurrent(P_cAnti, P_H, P_c, 1483, check)
      call createCurrent(P_H, P_H, 1505, check)
      call createCurrent(P_G0, P_G0, P_H, 621, check)
      call createCurrent(P_WpMinus, P_WpPlus, P_g, P_g, 1639, check)
      call createCurrent(P_bAnti, P_Zp, P_b, 996, check)
      call createCurrent(P_s, P_cAnti, P_GPlus, 205, check)
      call createCurrent(P_cAnti, P_c, P_A, 343, check)
      call createCurrent(P_WpMinus, P_nu_mu, P_ePlus, 699, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghAAnti, 1153, check)
      call createCurrent(P_A, P_WMinus, P_GPlus, 868, check)
      call createCurrent(P_WMinus, P_ghA, P_ghWmAnti, 300, check)
      call createCurrent(P_nu_tauAnti, P_WpPlus, P_tauMinus, 1006, check)
      call createCurrent(P_t, P_tAnti, P_Zp, 1025, check)
      call createCurrent(P_tauMinus, P_G0, P_tauPlus, 587, check)
      call createCurrent(P_Z, P_WPlus, P_GMinus, P_H, 813, check)
      call createCurrent(P_G0, P_ghWpAnti, P_ghWp, 101, check)
      call createCurrent(P_t, P_Zp, P_cAnti, 1232, check)
      call createCurrent(P_GMinus, P_nu_e, P_ePlus, 858, check)
      call createCurrent(P_WMinus, P_ePlus, P_nu_e, 1034, check)
      call createCurrent(P_WpPlus, P_g, P_WMinus, P_g, 1674, check)
      call createCurrent(P_g, P_WpMinus, P_WpPlus, P_g, 1607, check)
      call createCurrent(P_t, P_dAnti, P_WpMinus, 1338, check)
      call createCurrent(P_cAnti, P_GPlus, P_s, 201, check)
      call createCurrent(P_Z, P_G0, P_H, 1340, check)
      call createCurrent(P_tAnti, P_G0, P_t, 758, check)
      call createCurrent(P_muPlus, P_nu_mu, P_GMinus, 1422, check)
      call createCurrent(P_s, P_H, P_sAnti, 635, check)
      call createCurrent(P_Z, P_nu_eAnti, P_nu_e, 223, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_WMinus, 1279, check)
      call createCurrent(P_tAnti, P_Z, P_t, 1443, check)
      call createCurrent(P_WMinus, P_u, P_dAnti, 284, check)
      call createCurrent(P_G0, P_Z, P_Z, P_G0, 599, check)
      call createCurrent(P_d, P_dAnti, P_H, 880, check)
      call createCurrent(P_Z, P_WMinus, P_H, P_GPlus, 912, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_Z, 262, check)
      call createCurrent(P_G0, P_WPlus, P_WMinus, P_G0, 1042, check)
      call createCurrent(P_Zp, P_u, P_uAnti, 249, check)
      call createCurrent(P_cAnti, P_WpPlus, P_b, 629, check)
      call createCurrent(P_nu_mu, P_WMinus, P_muPlus, 1217, check)
      call createCurrent(P_d, P_WPlus, P_cAnti, 811, check)
      call createCurrent(P_tauMinus, P_nu_tauAnti, P_WPlus, 365, check)
      call createCurrent(P_g, P_Zp, P_Z, P_g, 1562, check)
      call createCurrent(P_A, P_A, P_WMinus, P_WPlus, 875, check)
      call createCurrent(P_G0, P_WPlus, P_GMinus, P_Z, 789, check)
      call createCurrent(P_s, P_WPlus, P_uAnti, 1412, check)
      call createCurrent(P_ePlus, P_WpMinus, P_nu_tau, 1187, check)
      call createCurrent(P_g, P_A, P_A, P_g, 1645, check)
      call createCurrent(P_WMinus, P_c, P_dAnti, 895, check)
      call createCurrent(P_s, P_H, P_dAnti, 1461, check)
      call createCurrent(P_sAnti, P_Z, P_s, 1076, check)
      call createCurrent(P_g, P_g, P_WMinus, P_WPlus, 1554, check)
      call createCurrent(P_WpPlus, P_b, P_uAnti, 672, check)
      call createCurrent(P_G0, P_H, P_G0, P_H, 1022, check)
      call createCurrent(P_g, P_WPlus, P_WMinus, P_g, 1563, check)
      call createCurrent(P_Z, P_muMinus, P_muPlus, 931, check)
      call createCurrent(P_Zp, P_d, P_dAnti, 103, check)
      call createCurrent(P_WMinus, P_WPlus, P_H, 147, check)
      call createCurrent(P_b, P_tAnti, P_GPlus, 656, check)
      call createCurrent(P_GMinus, P_WPlus, P_G0, P_A, 823, check)
      call createCurrent(P_ePlus, P_GMinus, P_nu_e, 210, check)
      call createCurrent(P_dAnti, P_A, P_d, 158, check)
      call createCurrent(P_GPlus, P_WMinus, 1503, check)
      call createCurrent(P_H, P_GMinus, P_A, P_WPlus, 197, check)
      call createCurrent(P_Z, P_tAnti, P_t, 1309, check)
      call createCurrent(P_WpPlus, P_muMinus, P_nu_muAnti, 1137, check)
      call createCurrent(P_b, P_tAnti, P_WpPlus, 677, check)
      call createCurrent(P_bAnti, P_WpMinus, P_t, 1089, check)
      call createCurrent(P_ePlus, P_nu_tau, P_WpMinus, 773, check)
      call createCurrent(P_tauMinus, P_GPlus, P_nu_tauAnti, 891, check)
      call createCurrent(P_Z, P_G0, P_WPlus, P_GMinus, 513, check)
      call createCurrent(P_GMinus, P_WPlus, P_Z, 1415, check)
      call createCurrent(P_ePlus, P_Zp, P_eMinus, 1075, check)
      call createCurrent(P_s, P_sAnti, 1523, check)
      call createCurrent(P_t, P_Zp, P_uAnti, 1383, check)
      call createCurrent(P_WPlus, P_g, P_g, P_WpMinus, 1655, check)
      call createCurrent(P_GMinus, P_A, P_WPlus, P_H, 1458, check)
      call createCurrent(P_WPlus, P_d, P_uAnti, 349, check)
      call createCurrent(P_WpPlus, P_b, P_tAnti, 700, check)
      call createCurrent(P_u, P_dAnti, P_GMinus, 13, check)
      call createCurrent(P_GMinus, P_GPlus, P_Z, P_Z, 235, check)
      call createCurrent(P_s, P_cAnti, P_WpPlus, 21, check)
      call createCurrent(P_g, P_G0, P_g, P_G0, 1668, check)
      call createCurrent(P_GMinus, P_bAnti, P_t, 1471, check)
      call createCurrent(P_nu_muAnti, P_nu_mu, P_Z, 1479, check)
      call createCurrent(P_g, P_Zp, P_g, P_Zp, 1609, check)
      call createCurrent(P_sAnti, P_c, P_WMinus, 516, check)
      call createCurrent(P_bAnti, P_t, P_GMinus, 968, check)
      call createCurrent(P_H, P_WMinus, P_Z, P_GPlus, 363, check)
      call createCurrent(P_A, P_WMinus, P_G0, P_GPlus, 292, check)
      call createCurrent(P_Zp, P_t, P_tAnti, 1048, check)
      call createCurrent(P_g, P_g, P_A, P_A, 1601, check)
      call createCurrent(P_WPlus, P_H, P_GMinus, P_A, 379, check)
      call createCurrent(P_WMinus, P_bAnti, P_t, 420, check)
      call createCurrent(P_muPlus, P_muMinus, P_Zp, 680, check)
      call createCurrent(P_WpMinus, P_nu_e, P_muPlus, 726, check)
      call createCurrent(P_GPlus, P_WMinus, P_Z, P_G0, 622, check)
      call createCurrent(P_g, P_WpMinus, P_g, P_WPlus, 1646, check)
      call createCurrent(P_dAnti, P_WMinus, P_c, 779, check)
      call createCurrent(P_G0, P_GMinus, P_WPlus, 422, check)
      call createCurrent(P_WPlus, P_d, P_cAnti, 1120, check)
      call createCurrent(P_WMinus, P_WPlus, P_A, 1142, check)
      call createCurrent(P_tauPlus, P_WpMinus, P_nu_mu, 1382, check)
      call createCurrent(P_Z, P_G0, P_GMinus, P_WPlus, 559, check)
      call createCurrent(P_A, P_GPlus, P_A, P_GMinus, 81, check)
      call createCurrent(P_sAnti, P_GMinus, P_c, 319, check)
      call createCurrent(P_H, P_u, P_uAnti, 490, check)
      call createCurrent(P_GPlus, P_Z, P_WMinus, 735, check)
      call createCurrent(P_GPlus, P_cAnti, P_s, 518, check)
      call createCurrent(P_WMinus, P_ghZ, P_ghWmAnti, 1199, check)
      call createCurrent(P_GPlus, P_H, P_GMinus, 987, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_GPlus, 182, check)
      call createCurrent(P_WpPlus, P_cAnti, P_s, 1110, check)
      call createCurrent(P_nu_eAnti, P_GPlus, P_eMinus, 1280, check)
      call createCurrent(P_Z, P_H, P_GMinus, P_WPlus, 971, check)
      call createCurrent(P_Z, P_WMinus, P_WPlus, P_A, 815, check)
      call createCurrent(P_GPlus, P_ghWm, P_ghZAnti, 844, check)
      call createCurrent(P_GPlus, P_GMinus, P_A, 745, check)
      call createCurrent(P_c, P_Zp, P_cAnti, 509, check)
      call createCurrent(P_g, P_bAnti, P_b, 1418, check)
      call createCurrent(P_sAnti, P_Zp, P_s, 1020, check)
      call createCurrent(P_dAnti, P_Zp, P_d, 19, check)
      call createCurrent(P_GPlus, P_d, P_cAnti, 32, check)
      call createCurrent(P_ghA, P_WMinus, P_ghWmAnti, 60, check)
      call createCurrent(P_H, P_WPlus, P_WMinus, P_H, 294, check)
      call createCurrent(P_sAnti, P_u, P_WMinus, 71, check)
      call createCurrent(P_uAnti, P_t, P_Zp, 383, check)
      call createCurrent(P_WMinus, P_muPlus, P_nu_mu, 1447, check)
      call createCurrent(P_u, P_GMinus, P_dAnti, 1459, check)
      call createCurrent(P_tAnti, P_WpPlus, P_d, 862, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_GMinus, 330, check)
      call createCurrent(P_A, P_GPlus, P_G0, P_WMinus, 233, check)
      call createCurrent(P_WMinus, P_GPlus, P_A, P_G0, 725, check)
      call createCurrent(P_WMinus, P_sAnti, P_c, 1015, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_WPlus, 74, check)
      call createCurrent(P_Zp, P_uAnti, P_c, 479, check)
      call createCurrent(P_GPlus, P_WMinus, P_Z, P_H, 151, check)
      call createCurrent(P_bAnti, P_b, P_A, 683, check)
      call createCurrent(P_WPlus, P_G0, P_WMinus, P_G0, 640, check)
      call createCurrent(P_G0, P_G0, P_GPlus, P_GMinus, 658, check)
      call createCurrent(P_GMinus, P_muPlus, P_nu_mu, 24, check)
      call createCurrent(P_WpPlus, P_d, P_tAnti, 214, check)
      call createCurrent(P_GMinus, P_A, P_A, P_GPlus, 985, check)
      call createCurrent(P_G0, P_muPlus, P_muMinus, 787, check)
      call createCurrent(P_GPlus, P_A, P_WMinus, 899, check)
      call createCurrent(P_eMinus, P_H, P_ePlus, 1401, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_WMinus, 781, check)
      call createCurrent(P_b, P_GPlus, P_tAnti, 704, check)
      call createCurrent(P_u, P_sAnti, P_WpMinus, 756, check)
      call createCurrent(P_H, P_WPlus, P_H, P_WMinus, 1204, check)
      call createCurrent(P_cAnti, P_Zp, P_c, 66, check)
      call createCurrent(P_WMinus, P_Z, P_GPlus, P_H, 778, check)
      call createCurrent(P_WpPlus, P_g, P_g, P_WMinus, 1558, check)
      call createCurrent(P_G0, P_GMinus, P_A, P_WPlus, 1293, check)
      call createCurrent(P_GMinus, P_GPlus, P_H, P_H, 306, check)
      call createCurrent(P_WMinus, P_A, P_Z, P_WPlus, 904, check)
      call createCurrent(P_nu_tau, P_WpMinus, P_ePlus, 1311, check)
      call createCurrent(P_b, P_bAnti, 1521, check)
      call createCurrent(P_c, P_dAnti, P_WMinus, 535, check)
      call createCurrent(P_G0, P_GPlus, P_A, P_WMinus, 1380, check)
      call createCurrent(P_Z, P_G0, 1513, check)
      call createCurrent(P_tauMinus, P_A, P_tauPlus, 22, check)
      call createCurrent(P_GMinus, P_WMinus, P_WPlus, P_GPlus, 1180, check)
      call createCurrent(P_GPlus, P_Z, P_A, P_GMinus, 260, check)
      call createCurrent(P_uAnti, P_g, P_u, 878, check)
      call createCurrent(P_GMinus, P_GPlus, P_G0, P_G0, 1247, check)
      call createCurrent(P_WPlus, P_G0, P_A, P_GMinus, 927, check)
      call createCurrent(P_GMinus, P_g, P_GPlus, P_g, 1584, check)
      call createCurrent(P_ePlus, P_A, P_eMinus, 387, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_A, 1068, check)
      call createCurrent(P_g, P_GMinus, P_g, P_GPlus, 1659, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Z, 503, check)
      call createCurrent(P_b, P_H, P_bAnti, 413, check)
      call createCurrent(P_WpPlus, P_nu_tauAnti, P_muMinus, 1484, check)
      call createCurrent(P_Z, P_muPlus, P_muMinus, 177, check)
      call createCurrent(P_g, P_g, P_Zp, P_g, 1643, check)
      call createCurrent(P_GPlus, P_Z, P_GMinus, P_Z, 731, check)
      call createCurrent(P_GPlus, P_WMinus, P_G0, P_A, 923, check)
      call createCurrent(P_nu_tau, P_ePlus, P_WpMinus, 881, check)
      call createCurrent(P_H, P_ghWp, P_ghWpAnti, 1336, check)
      call createCurrent(P_dAnti, P_d, P_G0, 168, check)
      call createCurrent(P_G0, P_cAnti, P_c, 1123, check)
      call createCurrent(P_WPlus, P_A, P_GMinus, P_G0, 327, check)
      call createCurrent(P_c, P_G0, P_cAnti, 737, check)
      call createCurrent(P_H, P_GMinus, P_GPlus, P_H, 375, check)
      call createCurrent(P_nu_mu, P_muPlus, P_GMinus, 472, check)
      call createCurrent(P_Z, P_H, P_WPlus, P_GMinus, 1156, check)
      call createCurrent(P_muMinus, P_muPlus, P_G0, 232, check)
      call createCurrent(P_G0, P_d, P_sAnti, 720, check)
      call createCurrent(P_g, P_A, P_g, P_g, 1586, check)
      call createCurrent(P_nu_muAnti, P_muMinus, P_GPlus, 68, check)
      call createCurrent(P_nu_tauAnti, P_tauMinus, P_WpPlus, 584, check)
      call createCurrent(P_H, P_G0, P_G0, 326, check)
      call createCurrent(P_GMinus, P_WPlus, P_H, P_Z, 23, check)
      call createCurrent(P_g, P_g, P_GMinus, P_GPlus, 1635, check)
      call createCurrent(P_uAnti, P_d, P_WPlus, 879, check)
      call createCurrent(P_A, P_Z, P_g, P_g, 1629, check)
      call createCurrent(P_GMinus, P_t, P_bAnti, 445, check)
      call createCurrent(P_GMinus, P_WPlus, P_WMinus, P_GPlus, 1246, check)
      call createCurrent(P_g, P_Zp, P_g, P_A, 1565, check)
      call createCurrent(P_GPlus, P_H, P_WMinus, 1088, check)
      call createCurrent(P_Zp, P_sAnti, P_d, 159, check)
      call createCurrent(P_g, P_g, P_g, P_A, 1587, check)
      call createCurrent(P_A, P_GMinus, P_GPlus, 664, check)
      call createCurrent(P_A, P_dAnti, P_d, 272, check)
      call createCurrent(P_Z, P_H, P_GPlus, P_WMinus, 819, check)
      call createCurrent(P_WMinus, P_g, P_WpPlus, P_g, 1663, check)
      call createCurrent(P_sAnti, P_s, 1520, check)
      call createCurrent(P_c, P_sAnti, P_GMinus, 166, check)
      call createCurrent(P_H, P_WMinus, P_WPlus, P_H, 244, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghA, 1118, check)
      call createCurrent(P_GPlus, P_GPlus, P_GMinus, P_GMinus, 600, check)
      call createCurrent(P_tAnti, P_t, 1522, check)
      call createCurrent(P_Z, P_Z, P_G0, P_G0, 134, check)
      call createCurrent(P_muMinus, P_nu_tauAnti, P_WpPlus, 568, check)
      call createCurrent(P_WPlus, P_GMinus, P_GPlus, P_WMinus, 1195, check)
      call createCurrent(P_u, P_uAnti, P_G0, 124, check)
      call createCurrent(P_bAnti, P_WpMinus, P_c, 1179, check)
      call createCurrent(P_H, P_tAnti, P_t, 1437, check)
      call createCurrent(P_t, P_G0, P_tAnti, 434, check)
      call createCurrent(P_H, P_H, P_Z, P_Z, 282, check)
      call createCurrent(P_WPlus, P_A, P_H, P_GMinus, 185, check)
      call createCurrent(P_GMinus, P_Z, P_H, P_WPlus, 27, check)
      call createCurrent(P_WPlus, P_Z, P_WMinus, 1314, check)
      call createCurrent(P_WPlus, P_tauMinus, P_nu_tauAnti, 1333, check)
      call createCurrent(P_WpPlus, P_tAnti, P_d, 767, check)
      call createCurrent(P_WpMinus, P_g, P_g, P_WpPlus, 1666, check)
      call createCurrent(P_WPlus, P_H, P_A, P_GMinus, 65, check)
      call createCurrent(P_cAnti, P_b, P_WpPlus, 1224, check)
      call createCurrent(P_ghZAnti, P_WPlus, P_ghWm, 130, check)
      call createCurrent(P_t, P_H, P_tAnti, 959, check)
      call createCurrent(P_GPlus, P_GMinus, P_H, P_H, 1473, check)
      call createCurrent(P_tauMinus, P_nu_eAnti, P_WpPlus, 597, check)
      call createCurrent(P_g, P_WPlus, P_g, P_WpMinus, 1594, check)
      call createCurrent(P_GPlus, P_WMinus, P_Z, 1030, check)
      call createCurrent(P_GMinus, P_GPlus, P_A, P_Z, 398, check)
      call createCurrent(P_t, P_GMinus, P_bAnti, 556, check)
      call createCurrent(P_bAnti, P_WpMinus, P_u, 1218, check)
      call createCurrent(P_muMinus, P_ePlus, P_Zp, 972, check)
      call createCurrent(P_GMinus, P_Z, P_Z, P_GPlus, 337, check)
      call createCurrent(P_WPlus, P_WpMinus, P_g, P_g, 1571, check)
      call createCurrent(P_H, P_G0, P_H, P_G0, 759, check)
      call createCurrent(P_ghZ, P_WMinus, P_ghWmAnti, 1381, check)
      call createCurrent(P_ePlus, P_eMinus, P_Zp, 388, check)
      call createCurrent(P_G0, P_WPlus, P_A, P_GMinus, 6, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghZAnti, 676, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_GPlus, 950, check)
      call createCurrent(P_s, P_G0, P_dAnti, 888, check)
      call createCurrent(P_t, P_uAnti, P_Zp, 805, check)
      call createCurrent(P_H, P_uAnti, P_u, 56, check)
      call createCurrent(P_u, P_A, P_uAnti, 920, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_WMinus, 1329, check)
      call createCurrent(P_b, P_WpPlus, P_uAnti, 1270, check)
      call createCurrent(P_A, P_u, P_uAnti, 1252, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_WPlus, 278, check)
      call createCurrent(P_GPlus, P_A, P_G0, P_WMinus, 30, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_GPlus, 766, check)
      call createCurrent(P_Z, P_GPlus, P_GMinus, 956, check)
      call createCurrent(P_WpPlus, P_WpMinus, 1532, check)
      call createCurrent(P_G0, P_ghWm, P_ghWmAnti, 304, check)
      call createCurrent(P_G0, P_A, P_WPlus, P_GMinus, 734, check)
      call createCurrent(P_s, P_uAnti, P_WpPlus, 1188, check)
      call createCurrent(P_WPlus, P_GMinus, P_H, P_Z, 1322, check)
      call createCurrent(P_GMinus, P_A, P_Z, P_GPlus, 253, check)
      call createCurrent(P_WPlus, P_GMinus, P_Z, P_G0, 539, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_G0, 1225, check)
      call createCurrent(P_WPlus, P_Z, P_Z, P_WMinus, 1334, check)
      call createCurrent(P_A, P_GPlus, P_GMinus, P_Z, 1212, check)
      call createCurrent(P_GMinus, P_GPlus, P_WPlus, P_WMinus, 1286, check)
      call createCurrent(P_muMinus, P_WPlus, P_nu_muAnti, 803, check)
      call createCurrent(P_g, P_Zp, P_A, P_g, 1623, check)
      call createCurrent(P_WMinus, P_Z, P_WPlus, P_A, 53, check)
      call createCurrent(P_G0, P_muMinus, P_muPlus, 474, check)
      call createCurrent(P_nu_mu, P_muPlus, P_WMinus, 1205, check)
      call createCurrent(P_WMinus, P_WPlus, P_A, P_Z, 1023, check)
      call createCurrent(P_b, P_Zp, P_dAnti, 1263, check)
      call createCurrent(P_GPlus, P_H, P_WMinus, P_Z, 795, check)
      call createCurrent(P_dAnti, P_s, P_Zp, 1275, check)
      call createCurrent(P_WPlus, P_A, P_GMinus, P_H, 1341, check)
      call createCurrent(P_muPlus, P_eMinus, P_Zp, 396, check)
      call createCurrent(P_GPlus, P_G0, P_G0, P_GMinus, 287, check)
      call createCurrent(P_WpPlus, P_nu_muAnti, P_tauMinus, 449, check)
      call createCurrent(P_WPlus, P_WMinus, P_A, P_A, 854, check)
      call createCurrent(P_WPlus, P_s, P_uAnti, 418, check)
      call createCurrent(P_WPlus, P_Z, P_H, P_GMinus, 952, check)
      call createCurrent(P_GPlus, P_WMinus, P_A, P_H, 863, check)
      call createCurrent(P_H, P_GPlus, P_Z, P_WMinus, 575, check)
      call createCurrent(P_H, P_ghWm, P_ghWmAnti, 293, check)
      call createCurrent(P_A, P_A, P_WPlus, P_WMinus, 51, check)
      call createCurrent(P_WpMinus, P_u, P_sAnti, 268, check)
      call createCurrent(P_Z, P_GMinus, P_GPlus, P_A, 1378, check)
      call createCurrent(P_g, P_g, P_G0, P_G0, 1665, check)
      call createCurrent(P_Zp, P_g, P_A, P_g, 1638, check)
      call createCurrent(P_WpMinus, P_t, P_sAnti, 973, check)
      call createCurrent(P_dAnti, P_GMinus, P_u, 1371, check)
      call createCurrent(P_ghWp, P_G0, P_ghWpAnti, 986, check)
      call createCurrent(P_GMinus, P_Z, P_GPlus, 974, check)
      call createCurrent(P_GPlus, P_muMinus, P_nu_muAnti, 1355, check)
      call createCurrent(P_g, P_g, P_Z, P_g, 1652, check)
      call createCurrent(P_WpMinus, P_nu_tau, P_ePlus, 1490, check)
      call createCurrent(P_muMinus, P_A, P_muPlus, 777, check)
      call createCurrent(P_u, P_uAnti, P_H, 910, check)
      call createCurrent(P_muPlus, P_WMinus, P_nu_mu, 861, check)
      call createCurrent(P_WPlus, P_GMinus, P_A, 1477, check)
      call createCurrent(P_g, P_Zp, P_g, P_g, 1593, check)
      call createCurrent(P_G0, P_s, P_dAnti, 644, check)
      call createCurrent(P_eMinus, P_Zp, P_tauPlus, 90, check)
      call createCurrent(P_u, P_WMinus, P_sAnti, 667, check)
      call createCurrent(P_Z, P_GMinus, P_GPlus, 761, check)
      call createCurrent(P_WPlus, P_WMinus, P_Z, P_Z, 109, check)
      call createCurrent(P_g, P_A, P_g, P_A, 1580, check)
      call createCurrent(P_ghWmAnti, P_H, P_ghWm, 1478, check)
      call createCurrent(P_tauMinus, P_WpPlus, P_nu_muAnti, 757, check)
      call createCurrent(P_b, P_bAnti, P_H, 1240, check)
      call createCurrent(P_ePlus, P_WMinus, P_nu_e, 315, check)
      call createCurrent(P_WMinus, P_WPlus, P_H, P_H, 887, check)
      call createCurrent(P_d, P_dAnti, P_g, 1312, check)
      call createCurrent(P_tauMinus, P_nu_tauAnti, P_WpPlus, 552, check)
      call createCurrent(P_WMinus, P_GPlus, P_A, 954, check)
      call createCurrent(P_A, P_WMinus, P_WPlus, P_A, 494, check)
      call createCurrent(P_GPlus, P_GMinus, P_GMinus, P_GPlus, 668, check)
      call createCurrent(P_b, P_Zp, P_bAnti, 1222, check)
      call createCurrent(P_GMinus, P_GPlus, P_WMinus, P_WPlus, 1391, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghA, 746, check)
      call createCurrent(P_GPlus, P_WPlus, P_WMinus, P_GMinus, 122, check)
      call createCurrent(P_ghWm, P_H, P_ghWmAnti, 998, check)
      call createCurrent(P_g, P_G0, P_G0, P_g, 1619, check)
      call createCurrent(P_g, P_A, P_Z, P_g, 1550, check)
      call createCurrent(P_ePlus, P_eMinus, P_Z, 1457, check)
      call createCurrent(P_tAnti, P_Zp, P_u, 1132, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_G0, 1062, check)
      call createCurrent(P_u, P_WpMinus, P_sAnti, 1146, check)
      call createCurrent(P_ePlus, P_tauMinus, P_Zp, 1122, check)
      call createCurrent(P_Z, P_GPlus, P_WMinus, P_H, 583, check)
      call createCurrent(P_Z, P_WPlus, P_H, P_GMinus, 241, check)
      call createCurrent(P_A, P_GPlus, P_WMinus, P_H, 804, check)
      call createCurrent(P_c, P_g, P_cAnti, 87, check)
      call createCurrent(P_c, P_cAnti, P_Z, 20, check)
      call createCurrent(P_Z, P_GPlus, P_A, P_GMinus, 801, check)
      call createCurrent(P_GPlus, P_GMinus, P_WMinus, P_WPlus, 562, check)
      call createCurrent(P_WPlus, P_WMinus, P_H, 179, check)
      call createCurrent(P_dAnti, P_Z, P_d, 63, check)
      call createCurrent(P_GPlus, P_G0, P_WMinus, P_A, 1182, check)
      call createCurrent(P_ePlus, P_nu_mu, P_WpMinus, 855, check)
      call createCurrent(P_g, P_ghG, P_ghGAnti, 911, check)
      call createCurrent(P_A, P_GMinus, P_WPlus, 105, check)
      call createCurrent(P_A, P_WPlus, P_GMinus, P_G0, 9, check)
      call createCurrent(P_Z, P_GPlus, P_GMinus, P_Z, 1292, check)
      call createCurrent(P_sAnti, P_WMinus, P_c, 1356, check)
      call createCurrent(P_uAnti, P_u, P_G0, 350, check)
      call createCurrent(P_GPlus, P_tAnti, P_b, 469, check)
      call createCurrent(P_H, P_H, P_GMinus, P_GPlus, 459, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_H, 131, check)
      call createCurrent(P_d, P_dAnti, P_A, 774, check)
      call createCurrent(P_ghZ, P_WPlus, P_ghWpAnti, 321, check)
      call createCurrent(P_Z, P_GPlus, P_G0, P_WMinus, 91, check)
      call createCurrent(P_GMinus, P_dAnti, P_u, 1475, check)
      call createCurrent(P_d, P_tAnti, P_WpPlus, 1000, check)
      call createCurrent(P_dAnti, P_b, P_Zp, 593, check)
      call createCurrent(P_uAnti, P_H, P_u, 1130, check)
      call createCurrent(P_g, P_WpPlus, P_WMinus, P_g, 1581, check)
      call createCurrent(P_g, P_g, P_A, P_Z, 1675, check)
      call createCurrent(P_WpPlus, P_nu_muAnti, P_muMinus, 1238, check)
      call createCurrent(P_nu_eAnti, P_tauMinus, P_WpPlus, 690, check)
      call createCurrent(P_WMinus, P_Z, P_Z, P_WPlus, 230, check)
      call createCurrent(P_WPlus, P_g, P_g, P_WMinus, 1572, check)
      call createCurrent(P_WPlus, P_WMinus, P_Z, 1203, check)
      call createCurrent(P_WPlus, P_muMinus, P_nu_muAnti, 1191, check)
      call createCurrent(P_Zp, P_bAnti, P_b, 1376, check)
      call createCurrent(P_eMinus, P_Zp, P_muPlus, 820, check)
      call createCurrent(P_WMinus, P_GMinus, P_WPlus, P_GPlus, 446, check)
      call createCurrent(P_WpMinus, P_nu_mu, P_muPlus, 1331, check)
      call createCurrent(P_tauPlus, P_Zp, P_eMinus, 136, check)
      call createCurrent(P_A, P_A, P_g, P_g, 1598, check)
      call createCurrent(P_g, P_A, P_g, P_Zp, 1538, check)
      call createCurrent(P_tauPlus, P_nu_e, P_WpMinus, 1101, check)
      call createCurrent(P_GMinus, P_GPlus, P_A, 944, check)
      call createCurrent(P_dAnti, P_u, P_WpMinus, 117, check)
      call createCurrent(P_b, P_bAnti, P_Z, 639, check)
      call createCurrent(P_nu_tau, P_WpMinus, P_muPlus, 1184, check)
      call createCurrent(P_Zp, P_uAnti, P_t, 505, check)
      call createCurrent(P_Z, P_Z, 1510, check)
      call createCurrent(P_nu_muAnti, P_GPlus, P_muMinus, 1084, check)
      call createCurrent(P_A, P_eMinus, P_ePlus, 709, check)
      call createCurrent(P_b, P_sAnti, P_Zp, 653, check)
      call createCurrent(P_H, P_GPlus, P_GMinus, 548, check)
      call createCurrent(P_WMinus, P_A, P_WPlus, 49, check)
      call createCurrent(P_WMinus, P_A, P_WPlus, P_A, 1450, check)
      call createCurrent(P_t, P_bAnti, P_WpMinus, 769, check)
      call createCurrent(P_WpPlus, P_nu_eAnti, P_muMinus, 421, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_ghZ, 883, check)
      call createCurrent(P_sAnti, P_Zp, P_d, 1435, check)
      call createCurrent(P_nu_tauAnti, P_muMinus, P_WpPlus, 955, check)
      call createCurrent(P_Z, P_sAnti, P_s, 712, check)
      call createCurrent(P_A, P_ghWp, P_ghWpAnti, 1213, check)
      call createCurrent(P_Zp, P_g, P_g, P_Zp, 1628, check)
      call createCurrent(P_G0, P_WMinus, P_A, P_GPlus, 487, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_Zp, 884, check)
      call createCurrent(P_tAnti, P_s, P_WpPlus, 1237, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_WPlus, 816, check)
      call createCurrent(P_Z, P_G0, P_G0, P_Z, 275, check)
      call createCurrent(P_GPlus, P_A, P_GMinus, P_Z, 1411, check)
      call createCurrent(P_Zp, P_eMinus, P_ePlus, 1403, check)
      call createCurrent(P_t, P_Zp, P_tAnti, 560, check)
      call createCurrent(P_Zp, P_dAnti, P_d, 409, check)
      call createCurrent(P_eMinus, P_nu_muAnti, P_WpPlus, 852, check)
      call createCurrent(P_GMinus, P_H, P_WPlus, 47, check)
      call createCurrent(P_s, P_uAnti, P_WPlus, 1465, check)
      call createCurrent(P_Z, P_GPlus, P_WMinus, 1296, check)
      call createCurrent(P_WPlus, P_GMinus, P_G0, P_A, 82, check)
      call createCurrent(P_nu_muAnti, P_Z, P_nu_mu, 283, check)
      call createCurrent(P_G0, P_G0, P_GMinus, P_GPlus, 526, check)
      call createCurrent(P_WpMinus, P_muPlus, P_nu_tau, 152, check)
      call createCurrent(P_GPlus, P_GMinus, P_H, 1445, check)
      call createCurrent(P_GPlus, P_nu_eAnti, P_eMinus, 36, check)
      call createCurrent(P_u, P_Zp, P_uAnti, 181, check)
      call createCurrent(P_nu_muAnti, P_muMinus, P_WPlus, 1429, check)
      call createCurrent(P_WMinus, P_g, P_g, P_WPlus, 1648, check)
      call createCurrent(P_WMinus, P_G0, P_GPlus, P_A, 850, check)
      call createCurrent(P_muMinus, P_WpPlus, P_nu_eAnti, 400, check)
      call createCurrent(P_c, P_Zp, P_uAnti, 1019, check)
      call createCurrent(P_WMinus, P_H, P_A, P_GPlus, 1033, check)
      call createCurrent(P_WMinus, P_Z, P_WPlus, P_Z, 502, check)
      call createCurrent(P_WMinus, P_Z, P_G0, P_GPlus, 675, check)
      call createCurrent(P_cAnti, P_G0, P_c, 1074, check)
      call createCurrent(P_WpMinus, P_dAnti, P_u, 426, check)
      call createCurrent(P_H, P_A, P_GPlus, P_WMinus, 812, check)
      call createCurrent(P_c, P_GMinus, P_sAnti, 566, check)
      call createCurrent(P_Zp, P_tauMinus, P_muPlus, 1197, check)
      call createCurrent(P_WPlus, P_s, P_cAnti, 1305, check)
      call createCurrent(P_WMinus, P_WPlus, 1534, check)
      call createCurrent(P_H, P_eMinus, P_ePlus, 373, check)
      call createCurrent(P_GMinus, P_G0, P_WPlus, 429, check)
      call createCurrent(P_bAnti, P_H, P_b, 437, check)
      call createCurrent(P_WpPlus, P_d, P_uAnti, 305, check)
      call createCurrent(P_G0, P_GMinus, P_G0, P_GPlus, 106, check)
      call createCurrent(P_Z, P_g, P_g, P_g, 1670, check)
      call createCurrent(P_Z, P_Z, P_H, P_H, 733, check)
      call createCurrent(P_g, P_s, P_sAnti, 1258, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_H, 807, check)
      call createCurrent(P_Zp, P_muPlus, P_tauMinus, 1055, check)
      call createCurrent(P_eMinus, P_G0, P_ePlus, 402, check)
      call createCurrent(P_H, P_A, P_WPlus, P_GMinus, 433, check)
      call createCurrent(P_WMinus, P_A, P_H, P_GPlus, 1190, check)
      call createCurrent(P_G0, P_WPlus, P_G0, P_WMinus, 38, check)
      call createCurrent(P_G0, P_WMinus, P_GPlus, 659, check)
      call createCurrent(P_c, P_A, P_cAnti, 1328, check)
      call createCurrent(P_Zp, P_b, P_sAnti, 229, check)
      call createCurrent(P_ghWmAnti, P_A, P_ghWm, 3, check)
      call createCurrent(P_GPlus, P_Z, P_G0, P_WMinus, 492, check)
      call createCurrent(P_Z, P_g, P_Zp, P_g, 1649, check)
      call createCurrent(P_c, P_dAnti, P_GMinus, 1395, check)
      call createCurrent(P_WMinus, P_WPlus, P_Z, P_A, 534, check)
      call createCurrent(P_tauPlus, P_Z, P_tauMinus, 688, check)
      call createCurrent(P_WpMinus, P_ePlus, P_nu_mu, 1454, check)
      call createCurrent(P_GPlus, P_GMinus, P_G0, P_G0, 598, check)
      call createCurrent(P_A, P_G0, P_GPlus, P_WMinus, 104, check)
      call createCurrent(P_Z, P_WMinus, P_A, P_WPlus, 126, check)
      call createCurrent(P_Zp, P_c, P_cAnti, 1425, check)
      call createCurrent(P_cAnti, P_WPlus, P_d, 1244, check)
      call createCurrent(P_bAnti, P_b, 1507, check)
      call createCurrent(P_g, P_g, P_g, 215, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_GPlus, 1414, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_WMinus, 1264, check)
      call createCurrent(P_eMinus, P_WpPlus, P_nu_muAnti, 663, check)
      call createCurrent(P_GMinus, P_g, P_g, P_GPlus, 1573, check)
      call createCurrent(P_muPlus, P_nu_e, P_WpMinus, 966, check)
      call createCurrent(P_t, P_tAnti, P_Z, 747, check)
      call createCurrent(P_ghZ, P_GMinus, P_ghWmAnti, 1044, check)
      call createCurrent(P_nu_tau, P_muPlus, P_WpMinus, 1467, check)
      call createCurrent(P_nu_tau, P_tauPlus, P_WMinus, 749, check)
      call createCurrent(P_GMinus, P_Z, P_WPlus, P_G0, 551, check)
      call createCurrent(P_WMinus, P_GPlus, P_G0, P_Z, 424, check)
      call createCurrent(P_WPlus, P_WMinus, P_A, 721, check)
      call createCurrent(P_A, P_muMinus, P_muPlus, 1438, check)
      call createCurrent(P_WPlus, P_H, P_H, P_WMinus, 1274, check)
      call createCurrent(P_GMinus, P_WMinus, P_GPlus, P_WPlus, 1097, check)
      call createCurrent(P_GMinus, P_GPlus, P_g, P_g, 1678, check)
      call createCurrent(P_bAnti, P_u, P_WpMinus, 1173, check)
      call createCurrent(P_ePlus, P_Zp, P_muMinus, 200, check)
      call createCurrent(P_H, P_ePlus, P_eMinus, 824, check)
      call createCurrent(P_WpMinus, P_g, P_WpPlus, P_g, 1546, check)
      call createCurrent(P_GMinus, P_WPlus, P_A, P_H, 1057, check)
      call createCurrent(P_ePlus, P_Z, P_eMinus, 359, check)
      call createCurrent(P_u, P_WpMinus, P_bAnti, 918, check)
      call createCurrent(P_g, P_g, P_A, P_Zp, 1553, check)
      call createCurrent(P_WpPlus, P_s, P_uAnti, 384, check)
      call createCurrent(P_nu_muAnti, P_WpPlus, P_tauMinus, 1041, check)
      call createCurrent(P_GMinus, P_ghZ, P_ghWmAnti, 649, check)
      call createCurrent(P_nu_e, P_Z, P_nu_eAnti, 1004, check)
      call createCurrent(P_dAnti, P_u, P_WMinus, 919, check)
      call createCurrent(P_uAnti, P_d, P_GPlus, 191, check)
      call createCurrent(P_s, P_sAnti, P_G0, 212, check)
      call createCurrent(P_dAnti, P_H, P_s, 508, check)
      call createCurrent(P_g, P_g, P_GPlus, P_GMinus, 1603, check)
      call createCurrent(P_GMinus, P_H, P_Z, P_WPlus, 143, check)
      call createCurrent(P_H, P_WPlus, P_Z, P_GMinus, 540, check)
      call createCurrent(P_u, P_WpMinus, P_dAnti, 54, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_ghWm, 694, check)
      call createCurrent(P_ePlus, P_H, P_eMinus, 1037, check)
      call createCurrent(P_eMinus, P_nu_eAnti, P_GPlus, 1407, check)
      call createCurrent(P_sAnti, P_H, P_d, 1400, check)
      call createCurrent(P_nu_muAnti, P_WPlus, P_muMinus, 941, check)
      call createCurrent(P_WPlus, P_A, P_WMinus, P_Z, 116, check)
      call createCurrent(P_Z, P_t, P_tAnti, 1255, check)
      call createCurrent(P_nu_e, P_ePlus, P_GMinus, 297, check)
      call createCurrent(P_ePlus, P_muMinus, P_Zp, 607, check)
      call createCurrent(P_Z, P_c, P_cAnti, 894, check)
      call createCurrent(P_tAnti, P_b, P_GPlus, 1327, check)
      call createCurrent(P_tAnti, P_c, P_Zp, 1161, check)
      call createCurrent(P_H, P_GPlus, P_H, P_GMinus, 1347, check)
      call createCurrent(P_sAnti, P_G0, P_d, 1131, check)
      call createCurrent(P_tauPlus, P_nu_tau, P_GMinus, 921, check)
      call createCurrent(P_b, P_g, P_bAnti, 102, check)
      call createCurrent(P_WPlus, P_G0, P_G0, P_WMinus, 1027, check)
      call createCurrent(P_WPlus, P_H, P_WMinus, P_H, 1008, check)
      call createCurrent(P_ghA, P_GMinus, P_ghWmAnti, 480, check)
      call createCurrent(P_muMinus, P_Zp, P_muPlus, 450, check)
      call createCurrent(P_ePlus, P_G0, P_eMinus, 1289, check)
      call createCurrent(P_H, P_GMinus, P_GPlus, 671, check)
      call createCurrent(P_sAnti, P_WpMinus, P_t, 138, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Z, 1410, check)
      call createCurrent(P_c, P_Zp, P_tAnti, 979, check)
      call createCurrent(P_WMinus, P_tauPlus, P_nu_tau, 1150, check)
      call createCurrent(P_WPlus, P_nu_tauAnti, P_tauMinus, 1124, check)
      call createCurrent(P_WpPlus, P_uAnti, P_b, 1214, check)
      call createCurrent(P_sAnti, P_d, P_H, 1040, check)
      call createCurrent(P_WpPlus, P_muMinus, P_nu_tauAnti, 328, check)
      call createCurrent(P_g, P_g, P_Z, P_A, 1615, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghZ, 31, check)
      call createCurrent(P_WpPlus, P_tauMinus, P_nu_muAnti, 655, check)
      call createCurrent(P_H, P_dAnti, P_d, 965, check)
      call createCurrent(P_WPlus, P_G0, P_GMinus, P_A, 1291, check)
      call createCurrent(P_WpPlus, P_d, P_cAnti, 1373, check)
      call createCurrent(P_muPlus, P_muMinus, P_Z, 1306, check)
      call createCurrent(P_ghWpAnti, P_G0, P_ghWp, 898, check)
      call createCurrent(P_H, P_c, P_cAnti, 150, check)
      call createCurrent(P_uAnti, P_u, P_A, 473, check)
      call createCurrent(P_g, P_dAnti, P_d, 808, check)
      call createCurrent(P_A, P_GMinus, P_Z, P_GPlus, 715, check)
      call createCurrent(P_bAnti, P_b, P_H, 957, check)
      call createCurrent(P_d, P_Z, P_dAnti, 893, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_H, 530, check)
      call createCurrent(P_bAnti, P_GMinus, P_t, 264, check)
      call createCurrent(P_Z, P_Z, P_WMinus, P_WPlus, 515, check)
      call createCurrent(P_t, P_A, P_tAnti, 592, check)
      call createCurrent(P_GPlus, P_WMinus, P_H, P_A, 497, check)
      call createCurrent(P_G0, P_Z, P_H, 748, check)
      call createCurrent(P_cAnti, P_c, P_Z, 1249, check)
      call createCurrent(P_uAnti, P_u, P_H, 717, check)
      call createCurrent(P_GMinus, P_sAnti, P_c, 1093, check)
      call createCurrent(P_ghZ, P_H, P_ghZAnti, 960, check)
      call createCurrent(P_A, P_WPlus, P_GMinus, 557, check)
      call createCurrent(P_A, P_tauMinus, P_tauPlus, 356, check)
      call createCurrent(P_uAnti, P_WpPlus, P_b, 1346, check)
      call createCurrent(P_WMinus, P_GPlus, P_Z, P_G0, 67, check)
      call createCurrent(P_WMinus, P_GPlus, P_G0, 29, check)
      call createCurrent(P_A, P_G0, P_GMinus, P_WPlus, 696, check)
      call createCurrent(P_g, P_g, P_WMinus, P_WpPlus, 1577, check)
      call createCurrent(P_WpMinus, P_nu_e, P_tauPlus, 88, check)
      call createCurrent(P_H, P_H, P_WPlus, P_WMinus, 661, check)
      call createCurrent(P_G0, P_WPlus, P_GMinus, 1201, check)
      call createCurrent(P_WMinus, P_G0, P_GPlus, P_Z, 361, check)
      call createCurrent(P_g, P_WPlus, P_g, P_WMinus, 1624, check)
      call createCurrent(P_d, P_dAnti, P_Zp, 938, check)
      call createCurrent(P_g, P_g, P_WpMinus, P_WPlus, 1555, check)
      call createCurrent(P_dAnti, P_G0, P_d, 1059, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_Z, 1018, check)
      call createCurrent(P_A, P_A, 1501, check)
      call createCurrent(P_g, P_ghGAnti, P_ghG, 754, check)
      call createCurrent(P_ghWm, P_G0, P_ghWmAnti, 209, check)
      call createCurrent(P_muMinus, P_muPlus, P_Z, 1316, check)
      call createCurrent(P_eMinus, P_Z, P_ePlus, 466, check)
      call createCurrent(P_Z, P_WPlus, P_GMinus, P_G0, 1362, check)
      call createCurrent(P_WPlus, P_cAnti, P_s, 906, check)
      call createCurrent(P_cAnti, P_d, P_WpPlus, 932, check)
      call createCurrent(P_cAnti, P_c, P_H, 1273, check)
      call createCurrent(P_Zp, P_tauPlus, P_muMinus, 45, check)
      call createCurrent(P_tAnti, P_g, P_t, 26, check)
      call createCurrent(P_t, P_WpMinus, P_bAnti, 1439, check)
      call createCurrent(P_GMinus, P_Z, P_G0, P_WPlus, 1127, check)
      call createCurrent(P_WpMinus, P_c, P_dAnti, 666, check)
      call createCurrent(P_ghZ, P_GPlus, P_ghWpAnti, 1468, check)
      call createCurrent(P_WMinus, P_WMinus, P_WPlus, P_WPlus, 1485, check)
      call createCurrent(P_u, P_uAnti, P_A, 1308, check)
      call createCurrent(P_A, P_WMinus, P_GPlus, P_H, 908, check)
      call createCurrent(P_A, P_Z, P_GMinus, P_GPlus, 187, check)
      call createCurrent(P_t, P_cAnti, P_Zp, 376, check)
      call createCurrent(P_GPlus, P_WMinus, P_G0, P_Z, 943, check)
      call createCurrent(P_g, P_Z, P_g, P_g, 1540, check)
      call createCurrent(P_WMinus, P_sAnti, P_u, 257, check)
      call createCurrent(P_A, P_WPlus, P_A, P_WMinus, 395, check)
      call createCurrent(P_muMinus, P_tauPlus, P_Zp, 442, check)
      call createCurrent(P_nu_muAnti, P_tauMinus, P_WpPlus, 1405, check)
      call createCurrent(P_WPlus, P_H, P_WMinus, 64, check)
      call createCurrent(P_Zp, P_g, P_g, P_A, 1680, check)
      call createCurrent(P_g, P_WpMinus, P_WPlus, P_g, 1654, check)
      call createCurrent(P_cAnti, P_WpPlus, P_s, 1058, check)
      call createCurrent(P_G0, P_ePlus, P_eMinus, 1284, check)
      call createCurrent(P_G0, P_G0, P_g, P_g, 1651, check)
      call createCurrent(P_A, P_GMinus, P_G0, P_WPlus, 196, check)
      call createCurrent(P_d, P_Zp, P_dAnti, 198, check)
      call createCurrent(P_WpPlus, P_eMinus, P_nu_muAnti, 1036, check)
      call createCurrent(P_WMinus, P_WPlus, P_GMinus, P_GPlus, 279, check)
    end subroutine createCurrents

    subroutine check_vertices_mdl()
      call createCurrents(.true.)
    end subroutine check_vertices_mdl

    subroutine get_vertex_lorentz_rank_mdl(ty,cc,mr)
      integer, intent(in) :: ty
      logical, intent(in) :: cc(0:)
      integer, intent(out) :: mr
      select case(ty)
      case(4)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(5)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(9)
        if (cc(1) .or. cc(2)) then
          mr = 1
        else
          mr = 0
        end if 
      case(17)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(19)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(20)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(21)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(24)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(25)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(29)
        if (cc(1) .or. cc(2)) then
          mr = 1
        else
          mr = 0
        end if 
      case(31)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(32)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(33)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(43)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(44)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(45)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(46)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(47)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(48)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(49)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(51)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(52)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(53)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(54)
        if (cc(1) .or. cc(2)) then
          mr = 1
        else
          mr = 0
        end if 
      case(57)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(61)
        if (cc(1) .or. cc(2)) then
          mr = 1
        else
          mr = 0
        end if 
      case(64)
        if (cc(1) .or. cc(2)) then
          mr = 1
        else
          mr = 0
        end if 
      case(67)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(68)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(70)
        if (cc(1) .or. cc(2)) then
          mr = 1
        else
          mr = 0
        end if 
      case default
        mr = 0
      end select 
    end subroutine get_vertex_lorentz_rank_mdl
end module class_vertices
